\name{Correlogram}
\alias{Correlogram}
\alias{correlogram.formula}
\alias{correlogram.phylo}
\title{Compute a correlogram}
\usage{
  correlogram.formula(formula, data)
  correlogram.phylo(x, phy, nclass = NULL, breaks = NULL)
}
\arguments{
  \item{x}{a vector containing the data to plot}
  \item{formula}{a formula of the kind \code{y ~ g1/../gn}, where \code{y} is the data to plot and all \code{g} are the nested levels}
  \item{data}{a dataframe containing all variables in the formula}
  \item{phy}{an object of class "phylo" width edge lengths}
  \item{breaks,nclass}{The class bounds or the number of classes to use. If both are NULL, compute Moran's I on the whole distance matrix.}
}
\description{
  Compute a correlogram from taxonomic variables or from a phylogenetic tree with branch lengths.
  The first method relies on the \code{\link{dist.taxo}} function, and the second relies on the \code{\link{discrete.dist}} function.
  Both methods send an object of class 'correlogram' to be plotted by
  the \code{\link{plot.correlogram}} method.
}
\details{
  See example of the \code{\link{Moran.I}} function to see how the \code{correlogram.formula} function works.
  To deal with phylogenies, the \code{correlogram.phylo} function creates classes according to distances intervals.
  Such intervals may be specified using the \code{breaks} argument or by giving a number of classes (\code{nclass} argument).
}
\value{
  An object of class 'correlogram', containing:
  \item{obs}{all measured Moran's I}
  \item{p.values}{the p-values of each I}
  \item{labels}{the names of each level}
}
\section{Warning}{
  \code{correlogram.phylo} will return NAs if void classes are used.
  This may happen if \code{breaks} if not properly defined, or sometimes with the \code{nclass= argument, depending on the tree used.
  Usually, you'll have to pull classes.
}
}
\author{Julien Dutheil \email{julien.dutheil@univ-montp2.fr}}
\seealso{
  \code{\link{plot.correlogram}}
}
\keyword{regression}
\examples{
  library(ape)### (the same analysis than in help(pic)...)
  data(carnivora)
  # Using the formula interface:
  co <- correlogram.formula(log10(SW) ~ Order/SuperFamily/Family/Genus, data=carnivora)
  co
  plot(co)

  # Using the phylo interface:
  cat("((((Homo:0.21,Pongo:0.21):0.28,",
     "Macaca:0.49):0.13,Ateles:0.62):0.38,Galago:1.00);",
     file = "ex.tre", sep = "\n")
  tree.primates <- read.tree("ex.tre")
  X <- c(4.09434, 3.61092, 2.37024, 2.02815, -1.46968)
  Y <- c(4.74493, 3.33220, 3.36730, 2.89037, 2.30259)
  # Since this is a small tree, 2 classes is a reasonable number:
  coX <- correlogram.phylo(X, tree.primates, nclass=2)
  coY <- correlogram.phylo(Y, tree.primates, nclass=2)
  plot(coX)
  plot(coY)
  # Nothing significant...
  # Computing Moran's I on the whole matrix:
  coX2 <- correlogram.phylo(X, tree.primates); coX2
  # Significant at the 5% level
  coY2 <- correlogram.phylo(Y, tree.primates); coY2
  # Not significant
  unlink("ex.tre") # delete the file "ex.tre"	
}

\eof
\name{GC.content}
\alias{GC.content}
\title{Content in GC from DNA Sequences}
\usage{
GC.content(x)
}
\arguments{
  \item{x}{a vector, a matrix, a data frame, or a list which contains
    the DNA sequences.}
}
\description{
  This function computes the percentage of G+C in a sample of DNA sequences.
}
\details{
  The  percentage of G+C is computed over all sequences in the
  sample. All missing or unknown sites are discarded from the
  computations. The present function actually uses the function
  \code{base.freq}.
}
\value{
  A single numeric value is returned.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{base.freq}}, \code{\link{seg.sites}}
}
\keyword{univar}

\eof
\name{Moran.I}
\alias{Moran.I}
\title{Moran's I Autocorrelation Index}
\usage{
  Moran.I(x, dist, scaled = FALSE)
}
\arguments{
  \item{x}{a numeric vector.}
  \item{dist}{a distance weigths matrix.}
  \item{scaled}{logical, indicate whether the index should be scaled to
    allow comparisons between indices (default to \code{FALSE}).}
}
\description{
  Computes Moran's I autocorrelation index of a given vector \code{x}
  according to a distance weights matrix \code{dist} using the method
  described by Gittleman and Kot (1990).
}
\details{
  The \code{dist} matrix is used as distance weights, and Moran's I indice
	is computed using the formula:
  \deqn{
		I = \frac{n}{S_0} \frac{\sum_{i=1}^n\sum_{j=1}^n w_{i,j}(y_i - \overline{y})(y_j - \overline{y})}{\sum_{i=1}^n {(y_i - \overline{y})}^2}
	}{
		\code{I = n/S0 * (sum\{i=1..n\} sum\{j=1..n\} wij(yi - ym))(yj - ym) / (sum\{i=1..n\} (yi - ym)^2)}
	}
  with
	\itemize{
		\item \eqn{y_i}{yi} = observations
		\item \eqn{w_{i,j}}{wij} = distance weight
		\item \eqn{n} = number of observations
		\item \eqn{S_0}{S0} = \eqn{\sum_{i=1}^n\sum_{j=1}^n wij}{\code{sum_{i=1..n} sum{j=1..n} wij}}
	}
  The value of I may be evaluated under two null hypotheses, normality and randomization.
  Only the randomization hypothesis is implemented for now.
}
\value{
  A list containing the attributes:
  \item{observed}{Moran's I index of \code{x}.}
  \item{expected}{Expected value of I under the null hypothesis.}
  \item{sd}{The standard deviation of I under the null hypothesis.}
  \item{p.value}{The p-value of having the observed value under the null hypothesis.}
}
\references{
  Gittleman, J. L. and M. Kot (1990) Adaptation: statistics and a null
  model for estimating phylogenetic effects. \emph{Systematic Zoology},
  \bold{39}, 227--241.
}
\author{Julien Dutheil \email{julien.dutheil@univ-montp2.fr}}
\seealso{
	\code{\link{dist.phylo}}, \code{\link{discrete.dist}}, \code{\link{dist.taxo}}
}
\keyword{regression}
\examples{
### This will draw the correlogram from Gittleman and Kot 1990
### This is only for example, consider function plot.correlogram() to draw correlograms.
library(ape)
data(carnivora)
attach(carnivora)
# Compute distance matrix for each taxonomic level:
dG  <- dist.taxo(Genus)
dF  <- dist.taxo(Family)
dSF <- dist.taxo(SuperFamily) 
dO  <- dist.taxo(Order)
# We draw the correlogram of average body weights, 
# with log10-transformed variable:
IG  <- Moran.I(log10(SW), dG        , scale=TRUE)
IF  <- Moran.I(log10(SW), dF  & !dG , scale=TRUE)
ISF <- Moran.I(log10(SW), dSF & !dF , scale=TRUE)
IO  <- Moran.I(log10(SW), dO  & !dSF, scale=TRUE)
# All Moran's I indices:
i <- c(IG$obs, IF$obs, ISF$obs, IO$obs)
# With their corresponding p-values:
p <- c(IG$p.v, IF$p.v, ISF$p.v, IO$p.v)
# Here's the legend:
l <- c("G", "F", "SF", "O")
# Draw the correlogram (using lattice library):
library(lattice)
# New Black & White device:
trellis.device(device=X11, new=FALSE, color=FALSE)
# Black circles are significant at the 5% level:
pch <- ifelse(p < 0.05, 19, 21)
# Plot it!
xyplot(i~ordered(l,levels=l), type="b", xlab="Rank", ylab="I / Imax",
    lty=2, lwd=2, cex=1.5, pch=pch, ylim=c(-0.75,0.75))
}

\eof
\name{NPRS.criterion}
\alias{NPRS.criterion}

\title{Objective Function Employed in Nonparametric Rate Smoothing}
\usage{
NPRS.criterion(phy, chrono, expo = 2, minEdgeLength = 1e-06)
}
\arguments{
  \item{phy}{A non-clock-like phylogenetic tree (i.e. an object of class \code{"phylo"}), where
    the branch lengths are measured in substitutions.}

  \item{chrono}{A chronogram, i.e. a clock-like tree (i.e. an object of class \code{"phylo"}), where
    the branch lengths are measured in absolute time.}

  \item{expo}{Exponent in the objective function (default value: 2)}
    
  \item{minEdgeLength}{Minimum edge length in the phylogram (default value: 1e-06). If any branch lengths are
    smaller then they will be set to this value. }  
}
\description{

 \code{NPRS.criterion} computes the objective function to be minimized in the NPRS
 (nonparametric rate smoothing) algorithm described in Sanderson (1997).
}

\details{
  Please refer to Sanderson (1997) for mathematical details. Note that
  is is not computationally efficient to optimize the branch lengths in
  a chronogram by using \code{NPRS.criterion} - please use
  \code{\link{chronogram}} instead.
}

\value{
\code{NPRS.criterion} returns the value of the objective function given a phylogram and a chronogram.}

}

\author{Gangolf Jobb (\url{http://www.treefinder.de}) and
Korbinian Strimmer (\url{http://www.stat.uni-muenchen.de/~strimmer/})
}

\seealso{
\code{\link{ratogram}},
\code{\link{chronogram}}.
}


\references{
  Sanderson, M. J. (1997) A nonparametric approach to estimating
    divergence times in the absence of rate constancy. \emph{Molecular
    Biology and Evolution}, \bold{14}, 1218--1231.
}

\examples{
library(ape)

# get tree
data("landplants.newick") # example tree in NH format
tree.landplants <- read.tree(text = landplants.newick)

# plot tree
tree.landplants
plot(tree.landplants, label.offset = 0.001)

# estimate chronogram
chrono.plants <- chronogram(tree.landplants)

# plot and write to file
plot(chrono.plants, label.offset = 0.001)
write.tree(chrono.plants, file = "chronogram.phy")

# value of NPRS function for our estimated chronogram
NPRS.criterion(tree.landplants, chrono.plants)
}
\keyword{manip}

\eof
\name{add.scale.bar}
\alias{add.scale.bar}
\title{Add a Scale Bar to a Phylogeny Plot}
\usage{
add.scale.bar(x, y, phy, bar = NULL)
}
\arguments{
  \item{x}{the x location of the legend.}
  \item{y}{the y location of the legend.}
  \item{phy}{an object of class \code{"phylo"}.}
  \item{bar}{a numeric value giving the length of the scale bar. If none
    is supplied (the default), a value is calculated from the data.}
}
\description{
  This function adds a horizontal bar giving the scale of the branch
  lengths to a plot of a phylogenetic tree on the current graphical
  device.
}
\details{
  This function can be used in two ways: either an object of class
  \code{"phylo"} is given and its branch lengths are used to determine
  the length of the scale bar, or the argument \code{bar} is specified
  and this is used as the length of the bar. In the latter case, the
  argument \code{phy} may be omitted.
}
\note{
  Since the coordinate system is not displayed when plotting a tree, it
  may be useful to use the function \code{\link[base]{locator}} to
  determine the \code{x} and \code{y} arguments.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{plot.phylo}}, \code{\link[base]{locator}}
}
\keyword{aplot}

\eof
\name{all.equal.phylo}
\alias{all.equal.phylo}
\title{Global Comparison of two Phylogenies}
\usage{
\method{all.equal}{phylo}(target, current, \dots)
}
\arguments{
  \item{target}{an object of class \code{"phylo"}.}
  \item{current}{an object of class \code{"phylo"}.}
  \item{...}{further arguments passed to or from other methods.}
}
\description{
  This function makes a global comparison of two phylogenetic trees.
}
\details{
  This function is meant to be an adaptation of the generic function
  \code{all.equal} for the comparison of phylogenetic trees.

  A single phylogenetic tree may have several representations in the Newick
  format and in the \code{"phylo"} class of objects used in `ape'. One
  aim of the present function is to be able to identify whether two
  objects of class \code{"phylo"} represent the same phylogeny.
}
\value{
  If both trees are strictly similar, the logical \code{TRUE} is
  returned. Otherwise, the different elements of the trees (numbers of
  tips, numbers of nodes, tip labels, tree topologies) are compared, and
  the results of these comparisons are printed.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link[base]{all.equal}} for the generic R function
}
\examples{
### maybe the simplest example of two representations
### for the same rooted tree
cat("((a:1,b:1):1,c:2);", file = "t1.tre")
cat("(c:2,(a:1,b:1):1);", file = "t2.tre")
t1 <- read.tree("t1.tre")
t2 <- read.tree("t2.tre")
all.equal(t1, t2)
### clean-up
unlink("t1.tre")
unlink("t2.tre")
}
\keyword{manip}

\eof
\name{ape-internal}
\alias{tree.build}
\alias{f.cherry.yule}
\alias{f.cherry.uniform}
\alias{sort.index}
\alias{nsca}
\alias{get.dna}
\alias{perm.rowscols}
\alias{mant.zstat}
\alias{lower.triang}
\alias{clado.build}
\alias{getDurations}
\alias{getEdgeLengths}
\alias{getExternalParams}
\alias{getNEdges}
\alias{getNFreeParams}
\alias{getRates}
\alias{objFuncLogScale}
\alias{optimTree}
\alias{phylogram}
\alias{prepareTree}
\alias{setTree}
\alias{buildTreeFromHclust}
\alias{buildTreeFromPhylo}
\alias{destroyTree}
\alias{edgeLengthsForPhylo}
\alias{getError}
\alias{getHclust}
\alias{getPhylo}
\alias{leftNodesForHclust}
\alias{lowerNodesForPhylo}
\alias{nEdges}
\alias{nNodes}
\alias{nodeHeightsForHclust}
\alias{nTips}
\alias{rightNodesForHclust}
\alias{tipLabelsForPhylo}
\alias{upperNodesForPhylo}
\alias{getMisawaTajima}
\alias{phylogram.plot}
\alias{cladogram.plot}
\alias{unrooted.plot}
\alias{unrooted.xy}
\alias{node.height}
\alias{node.height.clado}



\title{Internal Ape Functions}

\alias{birth.step}
\alias{death.step}
\alias{ht.move}
\alias{loglik.pop}
\alias{pos.move}


\description{
  Internal ape functions.
}
\note{
  These are not to be called by the user (or in some cases are just
  waiting for proper documentation to be written).
}
\keyword{internal}

\eof
\name{as.phylo}
\alias{as.phylo}
\alias{as.phylo.hclust}
\alias{as.hclust.phylo}

\title{Conversion between "phylo" and "hclust" trees}
\usage{
as.phylo(hc)
as.phylo.hclust(hc)
as.hclust.phylo(x, ...)
}
\arguments{
  \item{hc}{an object of class \code{"hclust"}), i.e. a clustering tree 
            computed using  \code{\link[stats]{hclust}}.}
  \item{x}{a phylogenetic tree, i.e. an object of class \code{"phy"}. To
    be converted into a \code{"hclust"} object the phylogenetic tree
    needs to be  ultra-metric and binary.}
  \item{...}{further arguments to be passed to or from other methods.}
}
\description{
 The function \code{as.phylo.hclust} (short form \code{as.phylo})
 converts a clustering tree computed using \code{\link[stats]{hclust}} into a
 phylogenetic tree, i.e. into an object of class \code{"phylo"}.
 
 The function \code{as.hclust.phylo} (short form \code{as.hclust})
 converts a phylogenetic tree into a \code{"hclust"} object.
}
\value{
An object of class \code{"hclust"} or \code{"phylo"}, respectively.
}
\seealso{
  \code{\link[stats]{hclust}}, \code{\link[stats]{as.hclust}},
  \code{\link{is.binary.tree}}, \code{\link{is.ultrametric}}
}
\author{Gangolf Jobb (\url{http://www.treefinder.de})
}

\examples{
library(ape)
library(stats) # for hclust and example data set

# create hclust object
data(USArrests)
hclust.tree<-hclust(dist(USArrests[1:6,]))
plot(hclust.tree)

# convert into phylo object
phylo.tree <- as.phylo(hclust.tree)
phylo.tree
plot(phylo.tree)

# phylogenetic tree is ultrametric and binary 
is.ultrametric(phylo.tree)
is.binary.tree(phylo.tree)

# convert back into hclust object
converted.tree <- as.hclust(phylo.tree)
plot(converted.tree)
}
\keyword{manip}

\eof
\name{balance}
\alias{balance}
\title{Balance of a Dichotomous Phylogenetic Tree}
\usage{
balance(phy)
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
}
\description{
  This function computes the balance of a phylogenetic tree, that is for
  each node of the tree the numbers of descendants (i.e. tips) on each
  of its daughter-branch. The tree must be fully dichotomous.
}
\value{
  a numeric matrix with two columns and one row for each node of the
  tree. The columns give the numbers of descendants on each
  daughter-branches (the order of both columns being arbitrary). If the
  phylogeny \code{phy} has an element \code{node.label}, this is used as
  rownames for the returned matrix; otherwise the numbers (of mode
  character) of the matrix \code{edge} of \code{phy} are used as rownames.
}
\references{
  For a discussion on tree balance:

  Aldous, D. J. (2001) Stochastic models and descriptive statistics for
  phylogenetic trees, from Yule to today. \emph{Statistical Science},
  \bold{16}, 23--34.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\keyword{manip}

\eof
\name{base.freq}
\alias{base.freq}
\title{Base frequencies from DNA Sequences}
\usage{
base.freq(x)
}
\arguments{
  \item{x}{a vector, a matrix, a data frame, or a list which contains
    the DNA sequences.}
}
\description{
  This function computes the relative frequencies (i.e. percentages) of
  the four DNA bases (adenine, cytosine, guanine, and thymidine) from a
  sample of sequences.
}
\details{
  The base frequencies are computed over all sequences in the
  sample. All missing or unknown sites are discarded from the
  computations.
}
\value{
  A table of relative frequencies with the names \code{"a"}, \code{"c"},
  \code{"g"}, and \code{"t"}.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{GC.content}}, \code{\link{seg.sites}}
}
\keyword{univar}

\eof
\name{bd.ext}
\alias{bd.ext}
\title{Extended Version of the Birth-Death Models to Estimate Speciation
  and Extinction Rates}
\usage{
bd.ext(phy, S)
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
  \item{S}{a numeric vector giving the number of species for each tip.}
}
\description{
  This function fits by maximum likelihood a birth-death model to the
  combined phylogenetic and taxonomic data of a given clade. The
  phylogenetic data are given by a tree, and the taxonomic data by the
  number of species for the its tips.
}
\details{
  A re-parametrization of the birth-death model studied by Kendall
  (1948) so that the likelihood has to be maximized over \emph{d/b} and
  \emph{b - d}, where \emph{b} is the birth rate, and \emph{d} the death
  rate.

  The standard-errors of the estimated parameters are  function computed
  using a normal approximations of the maximum likelihood estimates.

  Note that the function does not check that the tree is effectively
  ultrametric, so if it is not, the returned result may not be meaningful.
}
\references{
  Paradis, E. (2003) Analysis of diversification: combining phylogenetic
  and taxonomic data. \emph{Proceedings of the Royal Society of
    London. Series B. Biological Sciences}, \bold{270}, 2499--2505.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{birthdeath}}, \code{\link{branching.times}},
  \code{\link{diversi.gof}}, \code{\link{diversi.time}},
  \code{\link{ltt.plot}}, \code{\link{yule}}
}
\examples{
### An example from Paradis (2003) using the avian orders:
data(bird.orders)
### Number of species in each order from Sibley and Monroe (1990):
S <- c(10, 47, 69, 214, 161, 17, 355, 51, 56, 10, 39, 152,
       6, 143, 358, 103, 319, 23, 291, 313, 196, 1027, 5712)
bd.ext(bird.orders, S)
}
\keyword{models}

\eof
\name{bind.tree}
\alias{bind.tree}
\title{Binds Trees}
\usage{
bind.tree(x, y, node = -1, branch = NULL, position = NULL)
}
\arguments{
  \item{x}{an object of class \code{"phylo"}.}
  \item{y}{an object of class \code{"phylo"}.}
  \item{node}{a negative integer giving the node number of the tree
    \code{x} where the tree \code{y} is binded (by default -1, i.e. the
    root).}
  \item{branch}{an integer; if specified this gives the number of a tip
    or of a label of the tree \code{x} below which the tree \code{y} is
    binded.}
  \item{position}{a numeric value giving the position from the tip or
    node given by \code{branch} where the tree \code{y} is binded.}
}
\description{
  This function binds together two phylogenetic trees to result in a
  single object of class \code{"phylo"}.
}
\details{
  The argument \code{node} is ignored if \code{branch} is given. The
  argument \code{x} can be seen as the receptor tree, whereas \code{y}
  is the donor tree. The root of \code{y} is then sticked on a location
  of \code{x} specified by either the argument \code{node}, or the
  arguments \code{branch} and \code{position}. If \code{y} has a root
  edge, this is added as in internal branch in the resulting tree.
}
\value{
  an object of class \code{"phylo"}.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{drop.tip}}, \code{\link{root}}, \code{\link{rotate}}
}
\examples{
### binds the two clades of bird orders
cat("((Struthioniformes:21.8,Tinamiformes:21.8):4.1,",
    "((Craciformes:21.6,Galliformes:21.6):1.3,Anseriformes:22.9):3.0):2.1;",
    file = "ex1.tre", sep = "\n")
cat("(Turniciformes:27.0,(Piciformes:26.3,((Galbuliformes:24.4,",
    "((Bucerotiformes:20.8,Upupiformes:20.8):2.6,",
    "(Trogoniformes:22.1,Coraciiformes:22.1):1.3):1.0):0.6,",
    "(Coliiformes:24.5,(Cuculiformes:23.7,(Psittaciformes:23.1,",
    "(((Apodiformes:21.3,Trochiliformes:21.3):0.6,",
    "(Musophagiformes:20.4,Strigiformes:20.4):1.5):0.6,",
    "((Columbiformes:20.8,(Gruiformes:20.1,Ciconiiformes:20.1):0.7):0.8,",
    "Passeriformes:21.6):0.9):0.6):0.6):0.8):0.5):1.3):0.7):1.0;",
    file = "ex2.tre", sep = "\n")
tree.bird1 <- read.tree("ex1.tre")
tree.bird2 <- read.tree("ex2.tre")
unlink(c("ex1.tre", "ex2.tre")) # clean-up
birds <- bind.tree(tree.bird1, tree.bird2, branch = -1,
                   position = tree.bird1$root.edge)
birds
layout(matrix(c(1, 2, 3, 3), 2, 2))
plot(tree.bird1)
plot(tree.bird2)
plot(birds)
layout(matrix(1))
}
\keyword{manip}

\eof
\name{bird.families}
\alias{bird.families}
\title{Phylogeny of the Families of Birds From Sibley and Ahlquist}
\description{
  This data set describes the phylogenetic relationships of the families
  of birds as reported by Sibley and Ahlquist (1990). Sibley and
  Ahlquist inferred this phylogeny from an extensive number of DNA/DNA
  hybridization experiments. The ``tapestry'' reported by these two
  authors (more than 1000 species out of the ca. 9000 extant bird
  species) generated a lot of debates.

  The present tree is based on the relationships among families. A few
  families were not included in the figures in Sibley and Ahlquist, and
  thus are not included here as well. The branch lengths were calculated
  from the values of \eqn{\Delta T_{50}H}{Delta T50H} as found in Sibley
  and Ahlquist (1990, figs. 354, 355, 356, and 369).
}
\usage{
data(bird.families)
}
\format{
  The data are stored as an object of class \code{"phylo"} which
  structure is described in the help page of the function
  \code{\link{read.tree}}.
}
\source{
  Sibley, C. G. and Ahlquist, J. E. (1990) Phylogeny and classification
  of birds: a study in molecular evolution. New Haven: Yale University Press.
}
\seealso{
  \code{\link{read.tree}}, \code{\link{bird.orders}}
}
\examples{
data(bird.families)
op <- par()
par(cex = 0.3)
plot(bird.families)
par(op)
}
\keyword{datasets}

\eof
\name{bird.orders}
\alias{bird.orders}
\title{Phylogeny of the Orders of Birds From Sibley and Ahlquist}
\description{
  This data set describes the phylogenetic relationships of the orders
  of birds as reported by Sibley and Ahlquist (1990). Sibley and
  Ahlquist inferred this phylogeny from an extensive number of DNA/DNA
  hybridization experiments. The ``tapestry'' reported by these two
  authors (more than 1000 species out of the ca. 9000 extant bird
  species) generated a lot of debates.

  The present tree is based on the relationships among orders. The
  branch lengths were calculated from the values of \eqn{\Delta
    T_{50}H}{Delta T50H} as found in Sibley and Ahlquist (1990,
  fig. 353).
}
\usage{
data(bird.orders)
}
\format{
  The data are stored as an object of class \code{"phylo"} which
  structure is described in the help page of the function
  \code{\link{read.tree}}.
}
\source{
  Sibley, C. G. and Ahlquist, J. E. (1990) Phylogeny and classification
  of birds: a study in molecular evolution. New Haven: Yale University Press.
}
\seealso{
  \code{\link{read.tree}}, \code{\link{bird.families}}
}
\examples{
data(bird.orders)
plot(bird.orders)
}
\keyword{datasets}

\eof
\name{birthdeath}
\alias{birthdeath}
\title{Estimation of Speciation and Extinction Rates With Birth-Death Models}
\usage{
birthdeath(phy)
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
}
\description{
  This function fits by maximum likelihood a birth-death model to the
  branching times computed from a phylogenetic tree using the method of
  Nee et al. (1994).
}
\details{
  Nee et al. (1994) used a re-parametrization of the birth-death model
  studied by Kendall (1948) so that the likelihood has to be maximized
  over \emph{d/b} and \emph{b - d}, where \emph{b} is the birth rate,
  and \emph{d} the death rate. This is the approach used by the present
  function.

  This function computes the standard-errors of the estimated parameters
  using a normal approximations of the maximum likelihood estimates:
  this is likely to be inaccurate because of asymmetries of the
  likelihood function (Nee et al. 1995). In addition, 95 % confidence
  intervals of both parameters are computed using profile likelihood:
  they are particularly useful if the estimate of \emph{d/b} is at the
  boundary of the parameter space (i.e. 0, which is often the case).

  Note that the function does not check that the tree is effectively
  ultrametric, so if it is not, the returned result may not be meaningful.
}
\value{
  A NULL value is returned, the results are simply printed.
}
\references{
  Kendall, D. G. (1948) On the generalized ``birth-and-death''
  process. \emph{Annals of Mathematical Statistics}, \bold{19}, 1--15.

  Nee, S., May, R. M. and Harvey, P. H. (1994) The reconstructed
  evolutionary process. \emph{Philosophical Transactions of the Royal
    Society of London. Series B. Biological Sciences}, \bold{344}, 305--311.

  Nee, S., Holmes, E. C., May, R. M. and Harvey, P. H. (1995) Estimating
  extinctions from molecular phylogenies. in \emph{Extinction Rates},
  eds. Lawton, J. H. and May, R. M., pp. 164--182, Oxford University Press.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{branching.times}}, \code{\link{diversi.gof}},
  \code{\link{diversi.time}}, \code{\link{ltt.plot}},
  \code{\link{yule}}, \code{\link{bd.ext}}
}
\keyword{models}

\eof
\name{branching.times}
\alias{branching.times}
\title{Branching Times of a Phylogenetic Tree}
\usage{
branching.times(phy)
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
}
\description{
  This function computes the branching times of a phylogenetic tree,
  that is the distance from each node to the tips, under the assumption that
  the tree is ultrametric. Note that the function does not check that the
  tree is effectively ultrametric, so if it is not, the returned result
  may not be meaningful.
}
\value{
  a numeric vector with the branching times. If the phylogeny \code{phy}
  has an element \code{node.label}, this is used as names for the
  returned vector; otherwise the numbers (of mode character) of the
  matrix \code{edge} of \code{phy} are used as names.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\keyword{manip}

\eof
\name{carnivora}
\docType{data}
\alias{carnivora}
\title{Carnivora body sizes and life history traits}
\description{
  Dataset adapted from Gittleman (1986), including 2 morphological variables (body and brain sizes),  8 life history traits variables and 4 taxonomic variables.
}
\usage{data(carnivora)}
\format{
  A data frame with 112 observations on 17 variables.

  \tabular{rlll}{
    [,1]  \tab Order       \tab factor  \tab Carnivora order \cr
    [,2]  \tab SuperFamily \tab factor  \tab Super family (Caniformia or Feliformia) \cr
    [,3]  \tab Family      \tab factor  \tab Carnivora family \cr
    [,4]  \tab Genus       \tab factor  \tab Carnivora genus \cr
    [,5]  \tab Species     \tab factor  \tab Carnivora species \cr
    [,6]  \tab FW          \tab numeric \tab Female body weight (kg) \cr
    [,7]  \tab SW          \tab numeric \tab Average body weight of adult male and adult female (kg) \cr
    [,8]  \tab FB          \tab numeric \tab Female brain weight (g) \cr
    [,9]  \tab SB          \tab numeric \tab Average brain weight of adult male and adult female (g) \cr
    [,10] \tab LS          \tab numeric \tab Litter size \cr
    [,11] \tab GL          \tab numeric \tab Gestation length (days) \cr
    [,12] \tab BW          \tab numeric \tab Birth weigth (g) \cr
    [,13] \tab WA          \tab numeric \tab Weaning age (days) \cr
    [,14] \tab AI          \tab numeric \tab Age of independance (days) \cr
    [,15] \tab LY          \tab numeric \tab Longevity (mo) \cr
    [,16] \tab AM          \tab numeric \tab Age of sexual maturity (days) \cr
    [,17] \tab IB          \tab numeric \tab Inter-birth interval (mo) \cr
  }
}
\source{
  Gittleman, J. L. (1986) Carnivore life history patterns: allometric,
  phylogenetic and ecological associations. \emph{Ammerican Naturalist},
  \bold{127}: 744--771.
}
\examples{
  data(carnivora);
  # This is figure 1 of Gittleman 1986:
  library(lattice)
  trellis.device(color=FALSE)
  xyplot(BW ~ FW, groups=Family, data=carnivora, auto.key=TRUE, xlog=TRUE,
      scale=list(log=TRUE), ylim=c(1, 2000))
  trellis.device(color=FALSE)
  xyplot(BW ~ FB, groups=Family, data=carnivora, auto.key=TRUE, xlog=TRUE,
      scale=list(log=TRUE), ylim=c(1, 2000))
}
\keyword{datasets}


\eof
\name{cherry}
\alias{cherry}
\title{Number of Cherries and Null Models of Trees}
\usage{
cherry(phy)
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
}
\description{
  This function calculates the number of cherries (see definition below)
  on a phylogenetic tree, and tests the null hypotheses whether this
  number agrees with those predicted from two null models of trees (the
  Yule model, and the uniform model).
}
\value{
  A NULL value is returned, the results are simply printed.
}
\details{
  A cherry is a pair of adjacent tips on a tree. The tree can be either
  rooted or unrooted, but the present function considers only rooted
  trees. The probability distribution function of the number of cherries
  on a tree depends on the speciation/extinction model that generated
  the tree.

  McKenzie and Steel (2000) derived the probability
  distribution function of the number of cherries for two models: the
  Yule model and the uniform model. Broadly, in the Yule model, each extant
  species is equally likely to split into two daughter-species; in the
  uniform model, a branch is added to tree on any of the already
  existing branches with a uniform probability.

  The probabilities are computed using recursive formulae; however, for
  both models, the probability density function converges to a normal
  law with increasing number of tips in the tree. The function uses
  these normal approximations for a number of tips greater than or equal
  to 20.
}
\references{
  McKenzie, A. and Steel, M. (2000) Distributions of cherries for two
  models of trees. \emph{Mathematical Biosciences}, \bold{164}, 81--92.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{gammaStat}}
}
\keyword{univar}

\eof
\name{chiroptera}
\alias{chiroptera}
\title{Bat Phylogeny}
\description{
  This phylogeny of bats (Mammalia: Chiroptera) is a supertree (i.e. a
  composite phylogeny constructed from several sources; see source for
  details).
}
\usage{
data(chiroptera)
}
\format{
  The data are stored in RData (binary) format.
}
\source{
  Jones, K. E., Purvis, A., MacLarnon, A., Bininda-Emonds, O. R. P. and
  Simmons, N. B. (2002) A phylogenetic supertree of the bats (Mammalia:
  Chiroptera). \emph{Biological Reviews of the Cambridge Philosophical
    Society}, \bold{77}, 223--259.
}
\seealso{
  \code{\link{read.nexus}}, \code{\link{zoom}}
}
\examples{
data(chiroptera)
str(chiroptera)
op <- par()
par(cex = 0.3)
plot(chiroptera, type = "c")
par(op)
}
\keyword{datasets}

\eof
\name{chronogram}
\alias{chronogram}

\title{Chronogram Computed by Nonparametric Rate Smoothing}
\usage{
chronogram(phy, scale = 1, expo = 2, minEdgeLength = 1e-06)
}
\arguments{
  \item{phy}{A phylogenetic tree (i.e. an object of class
    \code{"phylo"}), where the branch lengths are measured in substitutions.}
  
  \item{scale}{Age of the root in the inferred chronogram (default value: 0). }
      
  \item{expo}{Exponent in the objective function (default value: 2)} 
  
  \item{minEdgeLength}{Minimum edge length in the phylogram (default
    value: 1e-06). If any branch lengths are smaller then they will be
    set to this value.}
}
\description{

 \code{chronogram} computes a chronogram from a phylogram by applying the NPRS
 (nonparametric rate smoothing) algorithm described in Sanderson (1997).
}

\details{
  Please refer to Sanderson (1997) for mathematical details
}

\value{
\code{chronogram} returns an object of class \code{"phylo"}. The branch lengths of this
tree will be clock-like and scaled so that the root node has age 1 (or the value
set by the option \code{scale}}

}

\author{Gangolf Jobb (\url{http://www.treefinder.de}) and
Korbinian Strimmer (\url{http://www.stat.uni-muenchen.de/~strimmer/})
}

\seealso{
\code{\link{ratogram}}, \code{\link{NPRS.criterion}}.
}


\references{
  Sanderson, M. J. (1997) A nonparametric approach to estimating
    divergence times in the absence of rate constancy. \emph{Molecular
    Biology and Evolution}, \bold{14}, 1218--1231.
}

\examples{
library(ape)

# get tree
data("landplants.newick") # example tree in NH format
tree.landplants <- read.tree(text = landplants.newick)

# plot tree
tree.landplants
plot(tree.landplants, label.offset = 0.001)

# estimate chronogram
chrono.plants <- chronogram(tree.landplants)

# plot and write to file
plot(chrono.plants, label.offset = 0.001)
write.tree(chrono.plants, file = "chronogram.phy")

# value of NPRS function for our estimated chronogram
NPRS.criterion(tree.landplants, chrono.plants)
}
\keyword{manip}

\eof
\name{coalescent.intervals}
\alias{coalescent.intervals}
\alias{coalescent.intervals.phylo}
\alias{coalescent.intervals.default}

\title{Coalescent Intervals}
\usage{
coalescent.intervals(x)
}
\arguments{
  \item{x}{either an ultra-metric phylogenetic tree (i.e. an object of
    class \code{"phylo"}) or, alternatively, a vector of interval lengths.}
}
\description{
 This function extracts or generates information about coalescent intervals
 (number of lineages, interval lengths, interval count, total depth) from
 a phylogenetic tree or a list of internode distances. The input tree
 needs to be ultra-metric (i.e. clock-like).
}
\value{
An object of class \code{"coalescentIntervals"} with the following entries:

  \item{lineages}{ A vector with the number of lineages at the start of each coalescent
    interval.}
  \item{interval.length}{ A vector with the length of each coalescent
    interval.}
  \item{interval.count}{ The total number of coalescent
    intervals.}
  \item{total.depth}{ The sum of the lengths of all coalescent
    intervals.}   
}
\seealso{
\code{\link{branching.times}}, \code{\link{collapsed.intervals}},
\code{\link{read.tree}}.
}

\author{Korbinian Strimmer (\url{http://www.stat.uni-muenchen.de/~strimmer/})}

\examples{
library(ape)

data("hivtree.newick") # example tree in NH format
tree.hiv <- read.tree(text = hivtree.newick) # load tree

ci <- coalescent.intervals(tree.hiv) # from tree
ci

data("hivtree.table") # same tree, but in table format
ci <- coalescent.intervals(hivtree.table$size) # from vector of interval lengths
ci
}
\keyword{manip}

\eof
\name{collapsed.intervals}
\alias{collapsed.intervals}

\title{Collapsed Coalescent Intervals}
\usage{
collapsed.intervals(ci, epsilon=0)
}
\arguments{
  \item{ci}{coalescent intervals (i.e. an object of class \code{"coalescentIntervals"}).}
  \item{epsilon}{collapsing parameter that controls the amount of smoothing
  (allowed range: from \code{0} to \code{ci$total.depth})}
}
\description{
 This function takes a \code{"coalescentIntervals"} objects and collapses neighbouring
 coalescent intervals into a single combined interval so that every collapsed interval is
 larger than \code{epsilon}. Collapsed coalescent intervals are used, e.g., to obtain the
 generalized skyline plot (\code{\link{skyline}}). For \code{epsilon = 0} no interval
 is collapsed.
}
\details{
Proceeding from the tips to the root of the tree each small
interval is pooled with the neighboring interval closer to the root. If the
neighboring interval is also small, then pooling continues until the composite
interval is larger than \code{epsilon}. Note that this approach prevents the
occurrence of zero-length intervals at the present. 
For more details see Strimmer and Pybus (2001).
}

\value{
An object of class \code{"collapsedIntervals"} with the following entries:

  \item{lineages}{ A vector with the number of lineages at the start of each coalescent
    interval.}
  \item{interval.length}{ A vector with the length of each coalescent
    interval.}
   \item{collapsed.interval}{A vector indicating for each coalescent interval to which
     collapsed interval it belongs.}
  \item{interval.count}{ The total number of coalescent
    intervals.}
   \item{collapsed.interval.count}{The number of collapsed intervals.}
  \item{total.depth}{ The sum of the lengths of all coalescent
    intervals.}    
  \item{epsilon}{The value of the underlying smoothing parameter.} 
}

\author{Korbinian Strimmer (\url{http://www.stat.uni-muenchen.de/~strimmer/})}

\seealso{
\code{\link{coalescent.intervals}},\code{\link{skyline}}.
}


\references{
  Strimmer, K. and O.G. Pybus (2001) Exploring the demographic history
  of DNA sequences using the generalized skyline plot. \emph{Molecular
    Biology and Evolution}, \bold{18}, 2298--2305.
}

\examples{
library(ape)

data("hivtree.table") # example tree 

# colescent intervals from vector of interval lengths
ci <- coalescent.intervals(hivtree.table$size) 
ci

# collapsed intervals
cl1 <- collapsed.intervals(ci,0)
cl2 <- collapsed.intervals(ci,0.0119)

cl1
cl2

}
\keyword{manip}

\eof
\name{compar.gee}
\alias{compar.gee}
\alias{print.compar.gee}
\title{Comparative Analysis with GEEs}
\usage{
compar.gee(formula, data = NULL, family = "gaussian", phy,
          scale.fix = FALSE, scale.value = 1)
}
\arguments{
  \item{formula}{a formula giving the model to be fitted.}
  \item{data}{the name of the data frame where the variables in
    \code{formula} are to be found; by default, the variables are looked
    for in the global environment.}
  \item{family}{a character string specifying the distribution assumed
    for the response; by default a Gaussian distribution (with link
    identity) is assumed (see \code{?family} for details on specifying
    the distribution, and on changing the link function).}
  \item{phy}{an object of class \code{"phylo"}.}
  \item{scale.fix}{logical, indicates whether the scale parameter should
    be fixed (TRUE) or estimated (FALSE, the default).}
  \item{scale.value}{if \code{scale.fix = TRUE}, gives the value for the
    scale (default: \code{scale.value = 1}).}
}
\description{
  This function performs the comparative analysis using generalized
  estimating equations as described by Paradis and Claude (2002).
}
\details{
  If a data frame is specified for the argument \code{data} and that
  data frame has rownames, then its values are matched to the tip labels
  of \code{phy}, otherwise its values are taken to be in the same order
  than the tip labels of \code{phy}.

  If \code{data = NULL}, then it is assumed that the variables are in
  the same order than the tip labels of \code{phy}.
}
\value{
  an object of class "compar.gee" with the following components:
  \item{call}{the function call, including the formula.}
  \item{nobs}{the number of observations.}
  \item{coefficients}{the estimated coefficients (or regression parameters).}
  \item{residuals}{the regression residuals.}
  \item{family}{a character string, the distribution assumed for the response.}
  \item{link}{a character string, the link function used for the mean function.}
  \item{scale}{the scale (or dispersion parameter).}
  \item{W}{the variance-covariance matrix of the estimated coefficients.}
  \item{dfP}{the phylogenetic degrees of freedom (see Paradis and Claude
    for details on this).}
}
\references{
  Paradis, E. and Claude J. (2002) Analysis of comparative data using
  generalized estimating equations. \emph{Journal of theoretical
    Biology}, \bold{216}, 000--000.
}

\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}

\seealso{
  \code{\link{read.tree}}, \code{\link{pic}}, \code{\link{compar.lynch}}
}
\examples{
### The example in Phylip 3.5c (originally from Lynch 1991)
### (the same analysis than in help(pic)...)
cat("((((Homo:0.21,Pongo:0.21):0.28,",
   "Macaca:0.49):0.13,Ateles:0.62):0.38,Galago:1.00);",
   file = "ex.tre", sep = "\n")
tree.primates <- read.tree("ex.tre")
X <- c(4.09434, 3.61092, 2.37024, 2.02815, -1.46968)
Y <- c(4.74493, 3.33220, 3.36730, 2.89037, 2.30259)
### Both regressions... the results are quite close to those obtained
### with pic().
compar.gee(X ~ Y, phy = tree.primates)
compar.gee(Y ~ X, phy = tree.primates)
### Now do the GEE regressions through the origin: the results are quite
### different!
compar.gee(X ~ Y - 1, phy = tree.primates)
compar.gee(Y ~ X - 1, phy = tree.primates)
unlink("ex.tre") # delete the file "ex.tre"
}
\keyword{regression}

\eof
\name{compar.lynch}
\alias{compar.lynch}
\title{Lynch's Comparative Method}
\usage{
compar.lynch(x, G, eps = 1e-4)
}
\arguments{
  \item{x}{eiher a matrix, a vector, or a data.frame containing the data
    with species as rows and variables as columns.}
  \item{G}{a matrix that can be interpreted as an among-species correlation
    matrix.}
  \item{eps}{a numeric value to detect convergence of the EM algorithm.}
}
\description{
  This function computes the heritable additive value and the residual
  deviation for continous characters, taking into account the
  phylogenetic relationships among species, following the comparative
  method described in Lynch (1991).  
}
\details{
  The parameter estimates are computed following the EM
  (expectation-maximization) algorithm. This algorithm usually leads to
  convergence but may lead to local optima of the likelihood
  function. It is recommended to run several times the function in order
  to detect these potential local optima. The `optimal' value for
  \code{eps} depends actually on the range of the data and may be
  changed by the user in order to check the stability of the parameter
  estimates. Convergence occurs when the differences between two
  successive iterations of the EM algorithm leads to differences between
  both residual and additive values less than or equal to \code{eps}.
} 
\note{
  The present function does not perform the estimation of ancestral
  phentoypes as proposed by Lynch (1991). This will be implemented in
  a future version.
}
\value{
  A list with the following components:
  \item{vare}{estimated residual variance-covariance matrix.}
  \item{vara}{estimated additive effect variance covariance matrix.}
  \item{u}{estimates of the phylogeny-wide means.}
  \item{A}{addtitive value estimates.}
  \item{E}{residual values estimates.}
  \item{lik}{logarithm of the likelihood for the entire set of observed
    taxon-specific mean.}
}
\references{
  Lynch, M. (1991) Methods for the analysis of comparative data in
  evolutionary biology. \emph{Evolution}, \bold{45}, 1065--1080.
}
\author{Julien Claude \email{claude@isem.univ-montp2.fr}}
\seealso{
  \code{\link{pic}}, \code{\link{compar.gee}}
}
\examples{
### The example in Lynch (1991)
cat("((((Homo:0.21,Pongo:0.21):0.28,",
   "Macaca:0.49):0.13,Ateles:0.62):0.38,Galago:1.00);",
   file = "ex.tre", sep = "\n")
tree.primates <- read.tree("ex.tre")
X <- c(4.09434, 3.61092, 2.37024, 2.02815, -1.46968)
Y <- c(4.74493, 3.33220, 3.36730, 2.89037, 2.30259)
compar.lynch(cbind(X, Y),
             G = vcv.phylo(tree.primates, cor = TRUE))
}
\keyword{regression}

\eof
\name{discrete.dist}
\alias{discrete.dist}
\title{Taxonomic Level from a Pairwise Distances Matrix}
\usage{
  discrete.dist(dist, inf, sup)
}
\arguments{
  \item{dist}{The pairwise distances matrix}
  \item{inf}{The lower bound of the class to use}
  \item{sup}{The upper bound of the class to use}
}
\description{
  Takes all distances in \code{dist} and set TRUE if the distance is < \code{sup} and >= \code{inf}.
  Sends the resulting boolean matrix.
}
\value{
  a boolean matrix of same size than \code{dist}.
}
\author{Julien Dutheil \email{julien.dutheil@univ-montp2.fr}}
\seealso{
	\code{\link{dist.taxo}} and \code{\link{dist.phylo}} for other distances.
  This function is used in \code{\link{correlogram.phylo}}.
}
\keyword{regression}

\eof
\name{dist.dna}
\alias{dist.dna}
\alias{dist.dna.JukesCantor}
\alias{dist.dna.TajimaNei}
\alias{dist.dna.Kimura}
\alias{dist.dna.Tamura}
\alias{dist.dna.TamuraNei}
\title{Pairwise Distances from DNA Sequences}
\usage{
dist.dna(x, y = NULL, variance = FALSE, gamma = NULL,
         method = "Kimura", basefreq = NULL, GCcontent = NULL)
dist.dna.JukesCantor(x, y, variance = FALSE, gamma = NULL)
dist.dna.TajimaNei(x, y, variance = FALSE, basefreq = NULL)
dist.dna.Kimura(x, y, variance = FALSE, gamma = NULL)
dist.dna.Tamura(x, y, variance = FALSE, GCcontent = NULL)
dist.dna.TamuraNei(x, y, variance = FALSE, basefreq = NULL,
                   gamma = NULL)
}
\arguments{
  \item{x}{either, a vector with a single DNA sequence, or a matrix of
    DNA sequences, or a list of DNA sequences (the latter can be taken
    from, e.g., \code{read.GenBank}).}
  \item{y}{a vector with a single DNA sequence.}
  \item{gamma}{a value for the gamma parameter which is possibly used to
    apply a gamma correction to the distances (by default \code{gamma =
      NULL} so no correction is applied).}
  \item{variance}{a logical indicating whether to compute the variances
    of the distances; defaults to \code{FALSE} so the variances are not
    computed.}
  \item{method}{a character string specifying the method used to compute
    the distance. Currently four choices are possible: \code{"JukesCantor"},
    \code{"TajimaNei"}, \code{"Kimura"} (the default), \code{"Tamura"},
    and \code{"TamuraNei"}.}
  \item{basefreq}{the base frequencies to be used in the computations
    (if applicable, i.e. if \code{method = "TajimaNei"}). By default, the
    base frequencies are computed from the whole sample of sequences.}
  \item{GCcontent}{the content in G+C to be used in the computations
    (if applicable, i.e. if \code{method = "Tamura"}). By default, this
    percentage is computed from the whole sample of sequences.}
}
\description{
  These functions compute a matrix of pairwise distances from DNA
  sequences using a model of DNA evolution. Five models are currently
  available.
}
\details{
  For the function \code{dist.dna}, if the argument \code{y} is specified,
  then it is binded to \code{x}, and the distances between all columns
  of the resulting matrix are computed; otherwise, \code{x} must be a
  matrix or a list. The four other functions take two single sequences
  as arguments.

  The function \code{dist.dna} actually calls one of the other function
  depending on the argument \code{method} (by default \code{"Kimura"})
  eventually passing the relevant arguments. For instance, specifying a
  value for the option \code{basefreq} has no effect if the option
  \code{method} is set to "Kimura" or "JukesCantor" (the base
  frequencies are assumed to be equal to 0.25 in both models).

  The molecular evolutionary models available through the option
  \code{method} have been extensively described in the literature. A
  brief description is given below; more details can be found in the
  References.

  \item{``JukesCantor''}{This model was developed by Jukes and Cantor
  (1969). It assumes that all substitutions (i.e. a change of a base by
  another one) have the same probability. This probability is the same
  for all sites along the DNA sequence. This last assumption can be
  relaxed by assuming that the substition rate varies among site
  following a gamma distribution which parameter must be given by the
  user. By default, no gamma correction is applied. Another assumption
  is that the base frequencies are balanced and thus equal to 0.25.}

  \item{``TajimaNei''}{Tajima and Nei (1984) developed an extension of the
  Jukes--Cantor model which relaxes the assumption of balanced base
  frequencies. The latter are estimated from the data. In the present
  function, the base frequencies are either given by the user, or
  estimated from the data. This allows the user to compute the base
  frequencies from a different (possibly much larger) data set than the
  one (s)he is interested in computing the distances. If the Tajima--Nei
  distances are computed with the function \code{dist.dna} and no base
  frequencies are given (\code{basefreq =  NULL}), then they are
  computed from the whole vectors, matrix, or list given as argument. If
  the distances are computed with the function \code{dist.dna.TajimaNei}
  and no base frequencies are given, then they are computed from both
  vectors given as argument.}

  \item{``Kimura''}{The distance derived by Kimura (1980), sometimes
  referred to as ``Kimura's 2-parameters distance'', has the same underlying
  assumptions than the Jukes--Cantor distance except that two kinds of
  substitutions are considered: transitions (A <-> G, C <-> T), and
  transversions (A <-> C, A <-> T, C <-> G, G <-> T). They are assumed
  to have different probabilities. A transition is the substitution of a
  purine (C, T) by another one, or the substitution of a pyrimidine (A,
  G) by another one. A transversion is the substitution of a purine by a
  pyrimidine, or vice-versa. Both transition and transversion rates are
  the same for all sites along the DNA sequence. Jin and Nei (1990)
  modified the Kimura model to allow for variation among sites following
  a gamma distribution. Like for the Jukes--Cantor model, the gamma parameter
  must be given by the user. By default, no gamma correction is applied.}

  \item{``Tamura''}{Tamura (1992) generalized the Kimura model by relaxing
  the assumption of equal base frequencies. This is done by taking into
  account the bias in G+C content in the sequences. The substitution
  rates are assumed to be the same for all sites along the DNA
  sequence.}

  \item{``TamuraNei''}{Tamura and Nei (1993) developed a model which
  assumes distinct rates for both kinds of transition (A <-> G versus C
  <-> T), and transversions. The base frequencies are not assumed to be
  equal and are estimated from the data. A gamma correction of the
  inter-site variation in substitution rates is possible.}
}
\value{
  a numeric matrix with possibly the names of the individuals (as given
  by the rownames of the argument \code{x}) as colnames and rownames (if
  \code{variance = FALSE}, the default), or a list of two matrices names
  \code{distances} and \code{variance}, respectively (if \code{variance =
    TRUE}).
}
\note{
  The models of DNA evolution available in `ape' follow somewhat those
  available in the software MEGA (Kumar et al. 2001).
}
\references{
  Felsenstein, J. (1993) Phylip (Phylogeny Inference Package) version
  3.5c. Department of Genetics, University of Washington.
  \url{http://evolution.genetics.washington.edu/phylip/phylip.html}

  Jukes, T. H. and C. R. Cantor. (1969) Evolution of protein
  molecules. in \emph{Mammalian Protein Metabolism}, ed. Munro, H. N.,
  pp. 21--132, New York: Academic Press.

  Kimura, M. (1980) A simple method for estimating evolutionary rates of
  base substitutions through comparative studies of nucleotide
  sequences. \emph{Journal of Molecular Evolution}, \bold{16}, 111--120.

  Kumar, S., Tamura, K., Jakobsen, I. B. and Nei, M. (2001) MEGA2:
  Molecular Evolutionary Genetics Analysis software.
  \emph{Bioinformatics}, \bold{17}, 1244--1245.
  \url{http://www.megasoftware.net/}

  Jin, L. and M. Nei (1990) Limitations of the evolutionary parsimony
  method of phylogenetic analysis. \emph{Molecular Biology and
    Evolution}, \bold{7}, 82--102.

  Tajima, F. and Nei., M. (1984) Estimation of evolutionary distance
  between nucleotide sequences. \emph{Molecular Biology and Evolution},
  \bold{1}, 269--285.

  Tamura, K. 1992. Estimation of the number of nucleotide substitutions
  when there are strong transition-transversion and G + C-content
  biases. \emph{Molecular Biology and Evolution}, \bold{9}, 678--687.

  Tamura, K. and M. Nei. 1993. Estimation of the number of nucleotide
  substitutions in the control region of mitochondrial DNA in humans and
  chimpanzees. \emph{Molecular Biology and Evolution}, \bold{10}, 512--526. 
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{read.GenBank}}, \code{\link{read.dna}}, \code{\link{write.dna}},
  \code{\link{dist.gene}}, \code{\link{dist.phylo}}
}
\keyword{manip}
\keyword{multivariate}

\eof
\name{dist.gene}
\alias{dist.gene}
\alias{dist.gene.pairwise}
\alias{dist.gene.percentage}
\title{Pairwise Distances from Genetic Data}
\usage{
dist.gene(x, method = "pairwise", variance = FALSE)
dist.gene.pairwise(x, variance = FALSE)
dist.gene.percentage(x, variance = FALSE)
}
\arguments{
  \item{x}{a matrix or a data frame.}
  \item{method}{a character string specifying the method used to compute
    the distances; only two choices are available: \code{"pairwise"},
    and \code{"percentage"}.}
  \item{variance}{a logical, indicates whether the variance of the
    distances should be returned (default to FALSE).}
}
\description{
  This function computes a matrix of distances between pairs of
  individuals from a matrix or a data frame of genetic data.
}
\details{
  This function is meant to be very general and accepts different kinds
  of data (alleles, haplotypes, DNA sequences, and so on). The rows of
  the data matrix represent the individuals, and the columns the loci.

  In the case of the pairwise method, the distance \eqn{d} between two
  individuals is the number of loci for which they differ, and the
  associated variance is \eqn{d(L - d)/L}, where \eqn{L} is the number
  of loci.

  In the case of the percentage method, this distance is divided by \eqn{L},
  and the associated variance is \eqn{d(1 - d)/L}.

  For more elaborate distances with DNA sequences, see the function
  \code{dist.dna}.
}
\value{
  either a numeric matrix with possibly the names of the individuals (as
  given by the rownames of the argument \code{x}) as colnames and rownames
  (if \code{variance = FALSE}, the default), or a list of two matrices names
  \code{distances} and \code{variance}, respectively (if \code{variance =
    TRUE}).
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{dist.dna}}, \code{\link{dist.phylo}}
}
\keyword{manip}


\eof
\name{dist.phylo}
\alias{dist.phylo}
\title{Pairwise Distances from a Phylogenetic Tree}
\usage{
dist.phylo(phy)
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
}
\description{
  This function computes the pairwise distances between the pairs of
  tips from a phylogenetic tree using the branch lengths of the latter.
}
\value{
  a numeric matrix with the names of the tips (as given by the element
  \code{tip.label} of the argument \code{phy}) as colnames and rownames.
}
\author{
  Julien Claude \email{claude@isem.univ-montp2.fr} and
  Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}
}
\seealso{
  \code{\link{read.tree}} to read tree files in Newick format
}
\keyword{manip}

\eof
\name{dist.taxo}
\alias{dist.taxo}
\title{Pairwise Distances from a Taxonomic Level}
\usage{
  dist.taxo(x)
}
\arguments{
  \item{x}{a vector describing a taxonomic level}
}
\description{
  This function computes the pairwise distances between the pairs of
  data in an alpha numeric vector.
  This vector contains taxonomic data, either as a full description 
  (for instance 'animal' and 'vegetal') or as a code (for instance '0' and '1').
  This function is useful for drawing correlograms.
}
\details{
  The matrix \eqn{m_{i,j}}{mij} will be:
  \enumerate{
    \item 0 if \eqn{i=j}{i=j};
    \item 0 if \eqn{i \neq j}{i!=j} and \eqn{x_i \neq x_j}{x[i]!=x[j]};
    \item 1 if \eqn{i \neq j}{i!=j} and \eqn{x_i = x_j}{x[i]==x[j]}.
  }
}
\value{
  a square matrix of size \code{length(x)}.
}
\author{Julien Dutheil \email{julien.dutheil@univ-montp2.fr}}
\seealso{
	\code{\link{Moran.I}} for example of use
}
\keyword{regression}

\eof
\name{diversi.gof}
\alias{diversi.gof}
\title{Tests of Constant Diversification Rates}
\usage{
diversi.gof(x, null = "exponential", z = NULL)
}
\arguments{
  \item{x}{a numeric vector with the branching times.}
  \item{null}{a character string specifying the null distribution for
    the branching times. Only two choices are possible: either
    \code{"exponential"}, or \code{"user"}.}
  \item{z}{used if \code{null = "user"}; gives the expected distribution
    under the model.}
}
\description{
  This function computes two tests of the distribution of branching
  times using the Cramr-von Mises and Anderson-Darling goodness-of-fit
  tests. By default, it is assumed that the diversification rate is
  constant, and an exponential distribution is assumed for the branching
  times. In this case, the expected distribution under this model is
  computed with a rate estimated from the data. Alternatively, the user
  may specify an expected cumulative density function (\code{z}): in this
  case, \code{x} and \code{z} must be of the same length.
}
\details{
  The Cramr-von Mises and Anderson-Darling tests compare the empirical
  density function (EDF) of the observations to an expected cumulative
  density function. By contrast to the Kolmogorov--Smirnov test where
  the greatest difference between these two functions is used, in both
  tests all differences are taken into account.

  The distributions of both test statistics depend on the null
  hypothesis, and on whether or not some parameters were estimated from
  the data. However, these distributions are not known precisely and
  critical values were determined by Stephens (1974) using
  simulations. These critical values were used for the present function.
}
\value{
  A NULL value is returned, the results are simply printed.
}
\references{
  Paradis, E. (1998) Testing for constant diversification rates using
  molecular phylogenies: a general approach based on statistical tests
  for goodness of fit. \emph{Molecular Biology and Evolution},
  \bold{15}, 476--479.

  Stephens, M. A. (1974) EDF statistics for goodness of fit and some
  comparisons. \emph{Journal of American Statistical Association},
  \bold{69}, 730--737.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{branching.times}}, \code{\link{diversi.time}}
  \code{\link{ltt.plot}}, \code{\link{birthdeath}}
}
\keyword{univar}

\eof
\name{diversi.time}
\alias{diversi.time}
\title{Analysis of Diversification with Survival Models}
\usage{
diversi.time(x, census = NULL, censoring.codes = c(1, 0), Tc = NULL)
}
\arguments{
  \item{x}{a numeric vector with the branching times.}
  \item{census}{a vector of the same length than `x' used as an
    indicator variable; thus, it must have only two values, one coding
    for accurately known branching times, and the other for censored
    branching times. This argument can be of any mode (numeric, character,
    logical), or can even be a factor.}
  \item{censoring.codes}{a vector of length two giving the codes used
    for \code{census}: by default 1 (accurately known times) and 0 (censored
    times). The mode must be the same than the one of \code{census}.}
  \item{Tc}{a single numeric value specifying the break-point time to
    fit Model C. If none is provided, then it is set arbitrarily to the
    mean of the analysed branching times.}
}
\description{
  This functions fits survival models to a set of branching times, some
  of them may be known approximately (censored). Three models are
  fitted, Model A assuming constant diversification, Model B assuming
  that diversification follows a Weibull law, and Model C assuming that
  diversification changes with a breakpoint at time `Tc'. The models are
  fitted by maximum likelihood.
}
\details{
  The principle of the method is to consider each branching time as an
  event: if the branching time is accurately known, then it is a failure
  event; if it is approximately knwon then it is a censoring event. An
  analogy is thus made between the failure (or hazard) rate estimated by
  the survival models and the diversification rate of the lineage. Time
  is here considered from present to past.

  Model B assumes a monotonically changing diversification rate. The
  parameter that controls the change of this rate is called beta. If
  beta is greater than one, then the diversification rate decreases
  through time; if it is lesser than one, the the rate increases through
  time. If beta is equal to one, then Model B reduces to Model A.
}
\value{
  A NULL value is returned, the results are simply printed.
}
\references{
  Paradis, E. (1997) Assessing temporal variations in diversification
  rates from phylogenies: estimation and hypothesis
  testing. \emph{Proceedings of the Royal Society of London. Series
    B. Biological Sciences}, \bold{264}, 1141--1147.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{branching.times}}, \code{\link{diversi.gof}}
  \code{\link{ltt.plot}}, \code{\link{birthdeath}}, ,
  \code{\link{bd.ext}}
}
\keyword{models}

\eof
\name{drop.tip}
\alias{drop.tip}
\title{Remove Tips in a Phylogenetic Tree}
\usage{
drop.tip(phy, tip, trim.internal = TRUE)
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
  \item{tip}{a vector of mode numeric or character specifying the tips
    to delete.}
  \item{trim.internal}{a logical specifying whether to delete the
    corresponding internal branches.}
}
\description{
  This function removes the terminal branches of a phylogenetic tree,
  possibly removing the corresponding internal branches.
}
\details{
  The argument \code{tip} can be either character or numeric. In the
  first case, it gives the labels of the tips to be deleted; in the
  second case the numbers of these labels in the vector
  \code{phy$tip.label} are given.

  If \code{trim.internal = FALSE}, the new tips are given \code{"NA"} as
  labels, unless there are node labels in the tree in which case they
  are used.
}
\value{
  an object of class \code{"phylo"}.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{bind.tree}}, \code{\link{root}}, \code{\link{rotate}}
}
\examples{
data(bird.families)
tip <- c(
"Eopsaltriidae", "Acanthisittidae", "Pittidae", "Eurylaimidae",
"Philepittidae", "Tyrannidae", "Thamnophilidae", "Furnariidae",
"Formicariidae", "Conopophagidae", "Rhinocryptidae", "Climacteridae",
"Menuridae", "Ptilonorhynchidae", "Maluridae", "Meliphagidae",
"Pardalotidae", "Petroicidae", "Irenidae", "Orthonychidae",
"Pomatostomidae", "Laniidae", "Vireonidae", "Corvidae",
"Callaeatidae", "Picathartidae", "Bombycillidae", "Cinclidae",
"Muscicapidae", "Sturnidae", "Sittidae", "Certhiidae",
"Paridae", "Aegithalidae", "Hirundinidae", "Regulidae",
"Pycnonotidae", "Hypocoliidae", "Cisticolidae", "Zosteropidae",
"Sylviidae", "Alaudidae", "Nectariniidae", "Melanocharitidae",
"Paramythiidae","Passeridae", "Fringillidae")
plot(drop.tip(bird.families, tip))
plot(drop.tip(bird.families, tip, trim.internal = FALSE))
}
\keyword{manip}

\eof
\name{gammaStat}
\alias{gammaStat}
\title{Gamma-Statistic of Pybus and Harvey}
\usage{
gammaStat(phy)
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
}
\description{
  This function computes the gamma-statistic which summarizes the
  information contained in the inter-node intervals of a phylogeny. It
  is assumed that the tree is ultrametric. Note that the function does
  not check that the tree is effectively ultrametric, so if it is not,
  the returned result may not be meaningful.
}
\value{
  a numeric vector of length one.
}
\details{
  The gamma-statistic is a summary of the information contained in the
  inter-node intervals of a phylogeny; it follows, under the assumption
  that the clade diversified with constant rates, a normal distribution
  with mean zero and standard-deviation unity (Pybus and Harvey
  2000). Thus, the null hypothesis that the clade diversified with
  constant rates may be tested with \code{1 -
    2*pnorm(abs(gammaStat(phy)))} for a two-tailed test, or \code{1 -
    pnorm(abs(gammaStat(phy)))} for a one-tailed test, both returning
  the corresponding P-value.
}
\references{
  Pybus, O. G. and Harvey, P. H. (2000) Testing macro-evolutionary
  models using incomplete molecular phylogenies. \emph{Proceedings of
    the Royal Society of London. Series B. Biological Sciences},
  \bold{267}, 2267--2272.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{branching.times}}, \code{\link{ltt.plot}}, \code{\link{skyline}}
}
\keyword{univar}

\eof
\name{heterozygosity}
\alias{heterozygosity}
\alias{H}
\title{Heterozygosity at a Locus Using Gene Frequencies}
\usage{
heterozygosity(x, variance = FALSE)
H(x, variance = FALSE)
}
\arguments{
  \item{x}{a vector or a factor.}
  \item{variance}{a logical indicating whether the variance of the 
    estimated heterozygosity should be returned (\code{TRUE}), the
    default being \code{FALSE}.}
}
\description{
  This function computes the mean heterozygosity from gene frequencies,
  and returns optionally the associated variance.
}
\value{
  a numeric vector of length one with the estimated mean heterozygosity
  (the default), or of length two if the variance is returned
  \code{variance = TRUE}.
}
\details{
  The argument \code{x} can be either a factor or a vector. If it is a
  factor, then it is taken to give the individual alleles in the
  population. If it is a numeric vector, then its values are taken to be
  the numbers of each allele in the population. If it is a non-numeric
  vector, it is a coerced as a factor.

  The mean heterozygosity is estimated with:

  \deqn{\hat{H} = \frac{n}{n-1} \left(1 - \sum_{i=1}^k p_i^2 \right)}{%
    H = n(1 - SUM (FROM i=1 TO k) p_i^2)/(n - 1)}

  where \eqn{n} is the number of genes in the sample, \eqn{k} is the
  number of alleles, and \eqn{p_i} is the observed (relative) frequency
  of the allele \eqn{i}.
}
\references{
  Nei, M. (1987) \emph{Molecular Evolutionary Genetics}. New York:
  Columbia University Press.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{theta.s}}
}
\keyword{manip}
\keyword{univar}

\eof
\name{hivtree}
\alias{hivtree}
\alias{hivtree.newick}
\alias{hivtree.table}

\title{Phylogenetic Tree of 193 HIV-1 Sequences}

\description{
  This data set describes an estimated clock-like phylogeny of 193 HIV-1
  group M sequences sampled in the Democratic Republic of Congo. 
}

\usage{
data(hivtree.newick)
data(hivtree.table)
}

\format{
  \code{hivtree.newick} is a string with the tree in Newick format.
  The data frame \code{hivtree.table} contains the corresponding internode
  distances.
}

\source{
  This is a data example from Strimmer and Pybus (2001).
}

\references{
  Strimmer, K. and O. G. Pybus. (2001) Exploring the demographic history
  of DNA sequences using the generalized skyline plot. \emph{Molecular
    Biology and Evolution}, \bold{18}, 2298--2305.
}

\examples{
library(ape)

# example tree in NH format (a string)
data("hivtree.newick") 
hivtree.newick

# generate file "hivtree.phy" in working directory
cat(hivtree.newick, file = "hivtree.phy", sep = "\n")
tree.hiv <- read.tree("hivtree.phy") # load tree
unlink("hivtree.phy") # delete the file "hivtree.phy"

plot(tree.hiv)

# table with list of internode distances
data("hivtree.table") 
hivtree.table


# construct coalescence intervals
ci <- coalescent.intervals(tree.hiv) # from tree
ci <- coalescent.intervals(hivtree.table$size) #from intervals
ci
}
\keyword{datasets}

\eof
\name{is.binary.tree}
\alias{is.binary.tree}
\title{Test for Binary Tree}
\usage{
is.binary.tree(tree)
}
\arguments{
  \item{tree}{phylogenetic tree (i.e. an object of class \code{"phylo"}).}
}
\description{
 This function tests whether a phylogenetic tree is binary, i.e. whether every node
 (including the root node) has exactly two descendant nodes.  In this case the number
 of edges in the tree equals 2 n - 2 where n is the number of taxa (tips) in the tree.
}
\value{
  \code{is.binary.tree} returns \code{TRUE} if \code{tree}
   is a fully binary phylogenetic tree, otherwise it returns \code{FALSE}.
}
\seealso{
\code{\link{read.tree}}, \code{\link{is.ultrametric}}
}

\author{Korbinian Strimmer (\url{http://www.stat.uni-muenchen.de/~strimmer/})}

\examples{
library(ape)

data("hivtree.newick") # example tree in NH format
tree.hiv <- read.tree(text = hivtree.newick) # load tree

is.binary.tree(tree.hiv)

plot(tree.hiv)

unlink("hivtree.phy") # delete the file "hivtree.phy"
}
\keyword{logic}

\eof
\name{is.ultrametric}
\alias{is.ultrametric}
\title{Test if a Tree is Ultrametric}
\usage{
is.ultrametric(phy, tol = .Machine$double.eps^0.5)
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
  \item{tol}{a numeric >= 0, variation below this value are considered
    non-significant (see details).}
}
\description{
  This function computes the distances from each tip to the root: if the
  variance of these distances is null, the tree is considered as
  ultrametric.
}
\value{
  a logical: \code{TRUE} if the tree is ultrametric, \code{FALSE}
  otherwise.
}
\details{
  The default value for \code{tol} is based on the numerical
  characteristics of the machine R is running on.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{is.binary.tree}}, \code{\link[base]{.Machine}}
}
\keyword{utilities}

\eof
\name{klastorin}
\alias{klastorin}

\title{Klastorin's (1982) method for classifying genes as suggested by Misawa
and Tajima (2000)}
\usage{
klastorin(phy)
}
\arguments{
  \item{phy}{a phylogenetic tree, i.e. an object of class \code{"phy"}. The root of the tree should make
   sense biologically.
  }
   
}
\description{
 The function \code{klastorin} uses the method by Klastorin's (1982) as suggested by Misawa
and Tajima (2000) for identifying groups within gene trees. 
 }
\value{
A vector indication the class affiliation for each sequence/taxon in the tree.

}
\seealso{
\code{\link{opsin}}.
}

\references{
   Klastorin T.D. (1982) An alternative method for hospital partition determination
   using hierarchical cluster analysis. \emph{Operations Research} \bold{30},1134--1147.

   Misawa, K. (2000) A simple method for classifying genes and a bootstrap
   test for classifications. \emph{Molecular
   Biology and Evolution}, \bold{17}, 1879--1884.
}


\author{Gangolf Jobb (\url{http://www.treefinder.de})
}

\examples{
library(ape)


# find groups in landplant tree 
data("landplants.newick") 
tree1 <- read.tree(text = landplants.newick)
plot(tree1, label.offset = 0.001)
klastorin(tree1) 
tree1$tip.label

# find groups in opsin tree 
data("opsin.newick") 
tree2 <- read.tree(text = opsin.newick)
plot(tree2,label.offset = 0.01)
groups <- klastorin(tree2) 
groups
tree2$tip.label[groups==1]
tree2$tip.label[groups==2]
tree2$tip.label[groups==3]
tree2$tip.label[groups==4]
tree2$tip.label[groups==5]
}
\keyword{manip}

\eof
\name{landplants}
\alias{landplants}
\alias{landplants.newick}

\title{Gene Tree of 36 Landplant rbcL Sequences}

\description{
  This data set describes a gene tree estimated from 36 landplant
  \emph{rbc}L sequences. 
}

\usage{
data(landplants.newick)
}

\format{
  \code{landplants.newick} is a string with the tree in Newick format.
}

\source{
  This tree is described in Sanderson (1997) and is also  a
  data example in the software package r8s
  (\url{http://ginger.ucdavis.edu/r8s/}).
}

\seealso{
\code{\link{chronogram}}, \code{\link{ratogram}}, \code{\link{NPRS.criterion}}.
}

\references{
  Sanderson, M. J. (1997) A nonparametric approach to estimating
    divergence times in the absence of rate constancy. \emph{Molecular
    Biology and Evolution}, \bold{14}, 1218--1231.
}

\examples{
library(ape)

# example tree in NH format (a string)
data("landplants.newick") 
landplants.newick

# get corresponding phylo object
tree.landplants <- read.tree(text = landplants.newick)

# plot tree
plot(tree.landplants, label.offset = 0.001)
}
\keyword{datasets}


\eof
\name{ltt.plot}
\alias{ltt.plot}
\alias{ltt.lines}
\alias{mltt.plot}
\title{Lineages Through Time Plot}
\usage{
ltt.plot(phy, xlab = "Time", ylab = "N", ...)
ltt.lines(phy, ...)
mltt.plot(phy, ..., dcol = TRUE, dlty = FALSE,
          legend = TRUE, xlab = "Time", ylab = "N")
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}; this could be an object
    of class \code{c("phylo", "multi.tree")} in the case of
    \code{mltt.plot}.}
  \item{xlab}{a character string (or a variable of mode character)
    giving the label for the x-axis (default is "Time").}
  \item{ylab}{idem for the y-axis (default is "N").}
  \item{...}{in the cases of \code{ltt.plot()} and \code{ltt.lines()}
    these are further (graphical) arguments to be passed to
    \code{plot()} or \code{lines()}, respectively (see \code{Details:}
    on how to transform the axes); in the case \code{mltt.plot()} these
    are additional trees to be plotted (see \code{Details:}).}
  \item{dcol}{a logical specifying whether the different curves should
    be differentiated with colors (default is \code{TRUE}).}
  \item{dlty}{a logical specifying whether the different curves should
    be differentiated with patterns of dots and dashes (default is
    \code{FALSE}).}
  \item{legend}{a logical specifying whether a legend should be
    plotted.}
}
\description{
  These functions plot, on the current graphical device, the minimum
  numbers of lineages through time from phylogenetic trees.
}
\details{
  \code{ltt.plot()} does a simple lineages through time (LTT)
  plot. Additional arguments (\code{...}) may be used to change, for
  instance, the limits on the axes (with \code{xlim} and/or
  \code{ylim}) or other graphical settings (\code{col} for the color,
  \code{lwd} for the line thickness, \code{lty} for the line type may be
  useful; see \code{\link[base]{par}} for an exhaustive listing of
  graphical parameters). The \eqn{y}-axis can be log-transformed by
  adding the following option: \code{log = "y"}.

  \code{ltt.lines()} adds a LTT curve to an existing plot. Additional
  arguments (\code{...}) may be used to change the settings of the added
  line. Of course, the settings of the already existing LTT plot cannot
  be altered this way.

  \code{mltt.plot()} does a multiple LTT plot taking as arguments one or
  several trees. These trees may be given as objects of class
  \code{"phylo"} (single trees) or \code{c("phylo", "multi.tree")}
  (multiple trees). Any number of objects may be given. This function is
  mainly for exploratory analyses with the advantages that the axes are
  set properly to view all lines, and the legend is plotted by
  default. For more flexible settings of line drawings, it is probably
  better to combine \code{ltt.plot()} with successive calls of
  \code{ltt.lines()} (see \code{Examples:}).
}
\references{
  Harvey, P. H., May, R. M. and Nee, S. (1994) Phylogenies without
  fossils. \emph{Evolution}, \bold{48}, 523--529.

  Nee, S., Holmes, E. C., Rambaut, A. and Harvey, P. H. (1995) Inferring
  population history from molecular phylogenies. \emph{Philosophical
    Transactions of the Royal Society of London. Series B. Biological
    Sciences}, \bold{349}, 25--31.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{skyline}}, \code{\link{branching.times}},
  \code{\link{birthdeath}}, \code{\link{bd.ext}},
  \code{\link[base]{plot}} for the basic plotting function in R
}
\examples{
data(bird.families)
data(bird.orders)
opar <- par(mfrow = c(2, 1))
ltt.plot(bird.families)
title("Lineages Through Time Plot of the Bird Families")
ltt.plot(bird.families, log = "y")
title(main = "Lineages Through Time Plot of the Bird Families",
      sub = "(with logarithmic transformation of the y-axis)")
par(opar)
### to plot the tree and the LTT plot together
tmp <- bird.families
tmp$tip.label <- rep("", length(bird.families$tip.label))
tmp2 <- bird.orders
tmp2$tip.label <- rep("", length(bird.orders$tip.label))
layout(matrix(1:4, 2, 2))
plot(tmp)
ltt.plot(bird.families, main = "Bird families")
plot(tmp2)
ltt.plot(bird.orders, main = "Bird orders")
layout(matrix(1))
mltt.plot(bird.families, bird.orders)
### Generates 10 random trees with 23 tips:
TR <- list()
for (i in 1:10) TR <- c(TR, list(rtree(23)))
### Give names to each tree:
names(TR) <- paste("random tree", 1:10)
### And specify the class of the list so that mltt.plot()
### does not trash it!
class(TR) <- c("phylo", "multi.tree")
### (This is non-sense: the trees are not ultrametric!)
mltt.plot(TR)
### Now rescale the branche lengths to have roughly the
### same scale than for the avian orders
for (i in 1:10) TR[[i]]$edge.length <- 7 * TR[[i]]$edge.length
### And now for something (not so) completely different...
### ... but still non-nense!
ltt.plot(bird.orders, lwd = 2)
for (i in 1:10) ltt.lines(TR[[i]], lty = 2)
legend(-10, 5, lwd = c(2, 1), lty = c(1, 2), bty = "n",
       legend = c("Bird orders", "Random trees"))
}
\keyword{hplot}
\keyword{aplot}

\eof
\name{mantel.test}
\alias{mantel.test}
\title{Mantel Test for Similarity of Two Matrices}
\usage{
mantel.test(m1, m2, nperm = 1000, graph = FALSE, ...)
}
\arguments{
  \item{m1}{a numeric matrix giving a measure of pairwise distances,
    correlations, or similarities among observations.}
  \item{m2}{a second numeric matrix giving another measure of pairwise
    distances, correlations, or similarities among observations.}
  \item{nperm}{the number of times to permute the data.}
  \item{graph}{a logical indicating whether to produce a summary graph
    (by default the graph is not plotted).}
  \item{...}{further arguments to be passed to \code{plot()} (to add a
    title, change the axis labels, and so on).}
}
\description{
  This function computes Mantel's permutation test for similarity of two
  matrices. It permutes the rows and columns of the two matrices
  randomly and calculates a Z-statistic.

}
\details{
  The function calculates a Z-statistic for the Mantel test, equal to
  the sum of the  pairwise product of the lower triangles of the
  permuted matrices, for each permutation of rows and columns. It
  compares the permuted distribution with the Z-statistic observed for
  the actual data.

  If \code{graph = TRUE}, the functions plots the density estimate of
  the permutation distribution along with the observed Z-statistic as a
  vertical line.

  The \code{...} argument allows the user to give further options to
  the \code{plot} function: the title main be changed with \code{main=},
  the axis labels with \code{xlab =}, and \code{ylab =}, and so on.
}
\value{
  \item{z.stat}{the Z-statistic (sum of rows*columns of lower triangle)
    of the data matrices.}
  \item{p}{P-value (quantile of the observed Z-statistic in the
    permutation distribution).}
}
\references{
  Mantel, N. (1967) The detection of disease clustering and a
  generalized regression approach. \emph{Cancer Research}, \bold{27},
  209--220.

  Manly, B. F. J. (1986) \emph{Multivariate statistical methods: a primer.}
  London: Chapman & Hall.}

\author{Original code in S by Ben Bolker \email{bolker@zoo.ufl.edu}, ported
  to R by Julien Claude \email{claude@isem.univ-montp2.fr}}

\examples{
q1 <- matrix(runif(36), nrow = 6)
q2 <- matrix(runif(36), nrow = 6)
mantel.test(q1, q2, graph = TRUE,
            main = "Mantel test: a random example with 6 X 6 matrices",
            xlab = "z-statistic", ylab = "Density",
            sub = "The vertical line shows the observed z-statistic")
}
\keyword{multivariate}

\eof
\name{mst}
\alias{mst}
\alias{plot.mst}
\title{Minimum Spanning Tree}
\usage{
mst(X)
\method{plot}{mst}(x, graph = "circle", x1 = NULL, x2 = NULL, \dots)
}
\arguments{
  \item{X}{either a matrix that can be interpreted as a distance matrix,
    or an object of class \code{"dist"}.}
  \item{x}{an object of class \code{"mst"} (e.g. returned by \code{mst()}).}
  \item{graph}{a character string indicating the type of graph to plot
    the minimum spanning tree; two choices are possible: \code{"circle"} where
    the observations are plotted regularly spaced on a circle, and
    \code{"nsca"} where the two first axes of a non-symmetric correspondence
    analysis are used to plot the observations (see Details below). If
    both arguments \code{x1} and \code{x2} are given, the argument
    \code{graph} is ignored.}
  \item{x1}{a numeric vector giving the coordinates of the observations
    on the \emph{x}-axis. Both \code{x1} and \code{x2} must be specified
    to be used.}
  \item{x2}{a numeric vector giving the coordinates of the observations
    on the \emph{y}-axis. Both \code{x1} and \code{x2} must be specified
    to be used.}
  \item{...}{further arguments to be passed to \code{plot()}.}
}
\description{
  The function \code{mst} finds the minimum spanning tree between a set of
  observations using a matrix of pairwise distances.

  The \code{plot} method plots the minimum spanning tree showing the
  links where the observations are identified by their numbers.
}
\details{
  These functions provide two ways to plot the minimum spanning tree which
  try to space as much as possible the observations in order to show as
  clearly as possible the links. The option \code{graph = "circle"}
  simply plots regularly the observations on a circle, whereas
  \code{graph = "nsca"} uses a non-symmetric correspondence analysis
  where each observation is represented at the centroid of its neighbours.

  Alternatively, the user may use any system of coordinates for the
  obsevations, for instance a principal components analysis (PCA) if the
  distances were computed from an original matrix of continous variables.
}
\value{
  an object of class \code{"mst"} which is a square numeric matrix of size
  equal to the number of observations with either \code{1} if a link
  between the corresponding observations was found, or \code{0}
  otherwise. The names of the rows  and columns of the distance matrix,
  if available, are given as rownames and colnames to the returned object.
}
\author{
  Yvonnick Noel \email{noel@univ-lille3.fr},
  Julien Claude \email{claude@isem.univ-montp2.fr} and
  Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}
}
\seealso{
  \code{\link{dist.dna}}, \code{\link{dist.gene}},
  \code{\link[stats]{dist}}, \code{\link[base]{plot}}
}
\examples{
library(stats)
n <- 20
X <- matrix(runif(n * 10), n, 10)
d <- dist(X)
PC <- prcomp(X)
M <- mst(d)
opar <- par()
par(mfcol = c(2, 2))
plot(M)
plot(M, graph = "nsca")
plot(M, x1 = PC$x[, 1], x2 = PC$x[, 2])
par(opar)
}
\keyword{multivariate}

\eof
\name{node.depth}
\alias{node.depth}
\title{Depth of Nodes and Tips}
\description{
  This function returns the depth of nodes and tips given by the number
  of descendants (1 is returned for tips).
}
\usage{
node.depth(x)
}
\arguments{
  \item{x}{the matrix `edge' of an object of class "phylo".}
}
\details{
  The depth of a node is computed as the number of tips which are its
  descendants. The value of 1 is given to the tips.
}
\value{
  A numeric vector with `names' being the ``numbers'' of the matrix
  `edge'.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\note{
  This function is actually called by plot.phylo(), and is unlikely to
  be called directly. However, it is documented separately since it may
  be useful for developpers.
}
\seealso{
  \code{\link{node.depth.edgelength}}, \code{\link{plot.phylo}}
}
\keyword{manip}

\eof
\name{node.depth.edgelength}
\alias{node.depth.edgelength}
\title{Distance from Root to Nodes and Tips}
\description{
  This function returns the distance from the root to each node and tip
  with respect to the edge lengths.
}
\usage{
node.depth.edgelength(x, el)
}
\arguments{
  \item{x}{the matrix `edge' of an object of class "phylo".}
  \item{el}{the vector `edge.length' of an object of class "phylo".}
}
\value{
  A numeric vector with `names' being the ``numbers'' of the matrix
  `edge'.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\note{
  This function is actually called by plot.phylo(), and is unlikely to
  be called directly. However, it is documented separately since it may
  be useful for developpers.
}
\seealso{
  \code{\link{node.depth}}, \code{\link{plot.phylo}}
}
\keyword{manip}

\eof
\name{opsin}
\alias{opsin}
\alias{opsin.newick}

\title{Gene Tree of 32 opsin Sequences}

\description{
  This data set describes a gene tree estimated from 32 opsin
  sequences. 
}

\usage{
data(opsin.newick)
}

\format{
  \code{opsin.newick} is a string with the tree in Newick format.
}

\source{
  This tree is described in Misawa and Tajima (2000) as an example
  for application of the Klastorin (1982) classification method.
}

\seealso{
\code{\link{klastorin}}.
}

\references{
  Misawa, K. (2000) A simple method for classifying genes and a bootstrap
  test for classifications. \emph{Molecular
    Biology and Evolution}, \bold{17}, 1879--1884.
}

\examples{
library(ape)

# example tree in NH format (a string)
data("opsin.newick") 
opsin.newick

# get corresponding phylo object
tree.opsin <- read.tree(text = opsin.newick)

# plot tree
plot(tree.opsin, label.offset = 0.01)
}
\keyword{datasets}


\eof
\name{pic}
\alias{pic}
\title{Phylogenetically Independent Contrasts}
\usage{
pic(x, phy, scaled = TRUE, var.contrasts = FALSE)
}
\arguments{
  \item{x}{a numeric vector.}
  \item{phy}{an object of class \code{"phylo"}.}
  \item{scaled}{logical, indicates whether the contrasts should be
    scaled with their expected variance (default to \code{TRUE}).}
  \item{var.contrasts}{logical, indicates whether the expected
    variance of the contrasts should be returned (default to \code{FALSE}).}
}
\description{
  Compute the phylogenetically independent contrasts using the method
  described by Felsenstein (1985).
}
\details{
  If \code{x} has names, its values are matched to the tip labels of
  \code{phy}, otherwise its values are taken to be in the same order
  than the tip labels of \code{phy}.
}
\value{
  either a vector of phylogenetically independent contrasts (if
  \code{var.contrasts = FALSE}), or a two-column matrix with the
  phylogenetically independent contrasts in the first column and their
  expected variance in the second column (if \code{var.contrasts = TRUE}).
}
\references{
  Felsenstein, J. (1985) Phylogenies and the comparative method.
  \emph{American Naturalist}, \bold{125}, 1--15.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{read.tree}}, \code{\link{compar.gee}}, \code{\link{compar.lynch}}
}
\examples{
### The example in Phylip 3.5c (originally from Lynch 1991)
cat("((((Homo:0.21,Pongo:0.21):0.28,",
   "Macaca:0.49):0.13,Ateles:0.62):0.38,Galago:1.00);",
   file = "ex.tre", sep = "\n")
tree.primates <- read.tree("ex.tre")
X <- c(4.09434, 3.61092, 2.37024, 2.02815, -1.46968)
Y <- c(4.74493, 3.33220, 3.36730, 2.89037, 2.30259)
names(X) <- names(Y) <- c("Homo", "Pongo", "Macaca", "Ateles", "Galago")
pic.X <- pic(X, tree.primates)
pic.Y <- pic(Y, tree.primates)
cor.test(pic.X, pic.Y)
lm(pic.Y ~ pic.X - 1) # both regressions
lm(pic.X ~ pic.Y - 1) # through the origin
unlink("ex.tre") # delete the file "ex.tre"
}
\keyword{regression}

\eof
\name{plot.correlogram}
\alias{plot.correlogram}
\title{Plot a Correlogram}
\usage{
  plot.correlogram(x, test.level=0.05, ...)
}
\arguments{
  \item{x}{an object of class 'correlogram'}
  \item{test.level}{The level above which points will be considered as non-significant}
  \item{...}{other parameters to be passed to the \code{xyplot} function}
}
\description{
  Draw a correlogram previously computed.
}
\details{
  The methods rely on the \code{\link[lattice]{xyplot}} function of the
  \pkg{lattice} package. Each significant point is plotted by a filled
  circle. Level of significance may be passed as an argument to the
  function.
}
\author{Julien Dutheil \email{julien.dutheil@univ-montp2.fr}}
\seealso{
  \code{\link[lattice]{xyplot}}, \code{\link{Correlogram}} for examples.
}
\keyword{hplot}

\eof
\name{plot.phylo}
\alias{plot.phylo}
\title{Plot Phylogenies}
\usage{
\method{plot}{phylo}(x, type = "phylogram", use.edge.length = TRUE,
             node.pos = NULL, show.node.label = FALSE,
             edge.color = NULL, edge.width = NULL, font = 3,
             adj = 0, srt = 0, no.margin = FALSE, root.edge = FALSE,
             label.offset = 0, underscore = FALSE, x.lim = NULL,
             lab4ut = "horizontal", ...)
}
\arguments{
  \item{x}{an object of class \code{"phylo"}.}
  \item{type}{a character string specifying the type of phylogeny to be
    drawn; it must be one of "phylogram" (the default), "cladogram",
    "unrooted", or any unambiguous abbreviation of these.}
  \item{use.edge.length}{a logical indicating whether to use the edge
    lengths of the phylogeny to draw the branches (the default) or not
    (if \code{FALSE}). This option has no effect if the object of class
    \code{"phylo"} has no `edge.length' element.}
  \item{node.pos}{a numeric taking the value 1 or 2 which specifies the
    vertical position of the nodes with respect to their descendants. If
    \code{NULL} (the default), then the value is determined in relation
    to `type' and `use.edge.length' (see details).}  
  \item{show.node.label}{a logical indicating whether to show the node
    labels on the phylogeny (defaults to \code{"FALSE"}, i.e. the labels
    are not shown).}
  \item{edge.color}{a vector of mode character giving the colours used
    to draw the branches of the plotted phylogeny. These are taken to be
    in the same order than the component \code{edge} of \code{phy}. If
    fewer colours are given than the length of \code{edge}, then the
    colours are recycled.}
  \item{edge.width}{a numeric vector giving the width of the branches of
    the plotted phylogeny. These are taken to be in the same order than
    the component \code{edge} of \code{phy}. If fewer widths are given
    than the length of \code{edge}, then these are recycled.}
  \item{font}{an integer specifying the type of font for the labels: 1
    (plain text), 2 (bold), 3 (italic, the default), or 4 (bold italic).}
  \item{adj}{a numeric specifying the justification of the text strings
    of the labels: 0 (left-justification, the default), 0.5 (centering),
    or 1 (right-justification). This option has no effect if \code{type
      = "unrooted"}.}
  \item{srt}{a numeric giving how much the labels are rotated in degrees
    (negative values are allowed resulting in clock-like rotation). This
    option has no effect if \code{type = "unrooted"}.}
  \item{no.margin}{a logical. If \code{TRUE}, the margins are set to
    zero and the plot uses all the space of the device (note that this
    was the behaviour of \code{plot.phylo} up to version 0.2-1 of `ape'
    with no way to modify it by the user, at least easily).}
  \item{root.edge}{a logical indicating whether to draw the root edge
    (defaults to FALSE); this has no effect if `use.edge.length = FALSE'
    or if `type = "unrooted"'.}
  \item{label.offset}{a numeric giving the space between the nodes and
    the tips of the phylogeny and their corresponding labels. This
    option has no effect if \code{type = "unrooted"}.}
  \item{underscore}{a logical specifying whether the underscores in tip
    labels should be written as spaces (the default) or left as are (if
    \code{TRUE}).}
  \item{x.lim}{a numeric giving the limit of the x-axis. If \code{NULL},
    this is computed with respect to various parameters such as the
    string lengths of the labels and the branch lengths.}
  \item{lab4ut}{(= labels for unrooted trees) a character string
    specifying the display of tip labels for unrooted trees: either
    \code{"horizontal"} where all labels are horizontal (the default),
    or \code{"axial"} where the labels are displayed in the axis of the
    corresponding terminal branches. This option has an effect only if
    \code{type = "unrooted"}.}
  \item{...}{further arguments to be passed to \code{plot()}.}
}
\description{
  This function plots a phylogenetic tree on the current graphical device.
}
\details{
  The formatting of the labels of both the nodes and the tips is the
  same.

  The new default behaviour is to use the current margins rather
  than to set them to zero. If \code{no.margin = TRUE}, the margins are
  set to zero and are not restored after plotting the tree, so that the
  user can access the coordinates system of the plot.

  The option `node.pos' allows the user to alter the vertical position
  (i.e. ordinates) of the nodes. If \code{node.pos = 1}, then the
  ordinate of a node is the mean of the ordinates of its direct
  descendants (nodes and/or tips). If \code{node.pos = 2}, then the
  ordinate of a node is the mean of the ordinates of all the tips of
  which it is the ancestor. If \code{node.pos = NULL} (the default),
  then its value is determined with respect to other options: if
  \code{type = "phylogram"} then `node.pos = 1'; if \code{type =
    "cladogram"} and \code{use.edge.length = FALSE} then `node.pos = 2';
  if \code{type = "cladogram"} and \code{use.edge.length = TRUE} then
  `node.pos = 1'.

  If the argument \code{x.lim} is not specified by the user, it is
  determined roughly by the function. This may not always give a nice
  result: the user may check these values with the (invisibly) returned
  list (see ``Value:'').
}
\value{
  The function returns invisibly a list with the following components
  which values are those used for the current plot:

  \item{type}
  \item{use.edge.length}
  \item{node.pos}
  \item{show.node.label}
  \item{edge.color}
  \item{edge.width}
  \item{font}
  \item{adj}
  \item{srt}
  \item{no.margin}
  \item{label.offset}
  \item{x.lim}

}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{read.tree}}, \code{\link{add.scale.bar}},
  \code{\link[base]{plot}} for the basic plotting function in R
}
\examples{
### An extract from Sibley and Ahlquist (1990)
cat("(((Strix_aluco:4.2,Asio_otus:4.2):3.1,",
   "Athene_noctua:7.3):6.3,Tyto_alba:13.5);",
   file = "ex.tre", sep = "\n")
tree.owls <- read.tree("ex.tre")
plot(tree.owls)
unlink("ex.tre") # delete the file "ex.tre"

### Show the types of trees.
layout(matrix(1:6, 3, 2))
plot(tree.owls, main = "With branch lengths")
plot(tree.owls, type = "c")
plot(tree.owls, type = "u")
plot(tree.owls, use.edge.length = FALSE, main = "Without branch lengths")
plot(tree.owls, type = "c", use.edge.length = FALSE)
plot(tree.owls, type = "u", use.edge.length = FALSE)
layout(matrix(1))

data(xenarthra)
op <- par()
\dontrun{par(ask = TRUE)}
plot(xenarthra)
### remove the margins...
plot(xenarthra, no.margin = TRUE)
### ... and use a smaller font size
par(cex = 0.8)
plot(xenarthra, no.margin = TRUE)
plot(xenarthra, type = "c", no.margin = TRUE, use.edge.length = FALSE)
par(op)

data(bird.orders)
### using random colours and thichness
plot(bird.orders,
     edge.color = sample(colors(), length(bird.orders$edge)/2),
     edge.width = sample(1:10, length(bird.orders$edge)/2, replace = TRUE))
title("Random colours and branch thickness")
### rainbow colouring...
X <- c("red", "orange", "yellow", "green", "blue", "purple")
plot(bird.orders,
     edge.color = sample(X, length(bird.orders$edge)/2, replace = TRUE),
     edge.width = sample(1:10, length(bird.orders$edge)/2, replace = TRUE))
title("Rainbow colouring")
plot(bird.orders, type = "c", use.edge.length = FALSE,
     edge.color = sample(X, length(bird.orders$edge)/2, replace = TRUE),
     edge.width = rep(5, length(bird.orders$edge)/2))
segments(rep(0, 6), 6.5:1.5, rep(2, 6), 6.5:1.5, lwd = 5, col = X)
text(rep(2.5, 6), 6.5:1.5, paste(X, "..."), adj = 0)
title("Character mapping is possible...")
par(cex = 0.75)
plot(bird.orders, "u", font = 1)
data(bird.families)
par(cex = 0.5)
plot(bird.families, "u", lab4ut = "axial", font = 1)
par(cex = 1)
}
\keyword{hplot}

\eof
\name{popsize}
\alias{mcmc.popsize}
\alias{extract.popsize}
\alias{plot.popsize}
\alias{lines.popsize}

\title{Reversible Jump MCMC to Infer Demographic History}
\usage{
mcmc.popsize(tree,nstep, thinning=1, burn.in=0,prior.lambda=0.5, max.nodes=30,progress.bar=TRUE)
extract.popsize(mcmc.out, credible.interval=0.95, time.points=200, thinning=1, burn.in=0)
plot.popsize(x, show.median=TRUE, show.years=FALSE, subst.rate, present.year, ...)
lines.popsize(x, show.median=TRUE,show.years=FALSE, subst.rate, present.year, ...)

}
\arguments{
  \item{tree}{Either an ultrametric tree (i.e. an object of class \code{"phylo"}), 
           or coalescent intervals (i.e. an object of class \code{"coalescentIntervals"}) }
  
  \item{nstep}{Number of MCMC steps, i.e. length of the Markov chain (suggested value: 10,000-50,000)}
  
  \item{thinning}{Thinning factor (suggest value: 10-100).}
  
  \item{burn.in}{Number of steps dropped from the chain to allow for a burn-in phase (suggest value: 1000)}
  
  \item{prior.lambda}{The lambda parameter of the prior distribution for the number of internal nodes of the approximating
  spline for the demographic function (suggested value: 0.1-1.0).}
  
  \item{max.nodes}{Upper limit for the number of internal nodes of the approximating spline (default: 30).}
  
  \item{progress.bar}{Show progress bar during the MCMC run.}	  
  
  \item{mcmc.out}{output from \code{mcmc.popsize} - this is needed as input for \code{extract.popsize}}
  
 \item{credible.interval}{"width" of the confidence band (default: 0.95)}

 \item{time.points}{number of discrete time points in the table output by \code{extract.popsize}}

 \item{x}{table with population size versus time, as computed by \code{extract.popsize} }

 \item{show.median}{plot median rather than mean as point estimate for demographic function (default: TRUE)}

  \item{show.years}{option that determines whether the time is plotted in units of
        of substitutions (default) or in years (requires specification of substution rate
	and year of present).}
	
\item{subst.rate}{substitution rate (see option show.years).}	
\item{present.year}{present year (see option show.years).}	

  \item{\dots}{further arguments to be passed on  to \code{plot}.}  
}
\description{
 These functions implement a reversible jump MCMC framework to infer the demographic history,
 as well as corresponding confidence bands,
 from a genealogical tree. The computed demographic history is a continous
 and smooth function in time.
 
 
 \code{mcmc.popsize} runs the actual MCMC chain and outputs information about the
 sampling steps, \code{extract.popsize} generates from this MCMC
 output a table of population size in time, and  \code{plot.popsize} and \code{lines.popsize}
 provide utility functions to plot the corresponding demographic functions.
}

\details{
 Please refer to Opgen-Rhein et al. (2004) for methodological details, and the help page of
 \code{\link{skyline}} for information on a related approach.
}


\author{Rainer Opgen-Rhein (\url{http://www.stat.uni-muenchen.de/~opgen/}) and 
        Korbinian Strimmer (\url{http://www.stat.uni-muenchen.de/~strimmer/}).
        Parts of the rjMCMC sampling procedure are adapted from R code by Karl Browman
	 (\url{http://www.biostat.jhsph.edu/~kbroman/})}

\seealso{
\code{\link{skyline}} and \code{\link{skylineplot}}. }



\references{
  Opgen-Rhein, R., L. Fahrmeir, and K. Strimmer, K. 2003. Inference of demographic history
  from genealogical trees using reversible jump Markov chain Monte Carlo. 
  Submitted to \emph{BMC Evolutionary Biology}.
}


\examples{
library(ape)

# get tree
data("hivtree.newick") # example tree in NH format
tree.hiv <- read.tree(text = hivtree.newick) # load tree

# run mcmc chain
mcmc.out <- mcmc.popsize(tree.hiv, nstep=100, thinning=1, burn.in=0) # toy run
#mcmc.out <- mcmc.popsize(tree.hiv, nstep=10000, thinning=5, burn.in=500) # remove comments!!

# make list of population size versus time
popsize  <- extract.popsize(mcmc.out)

# plot and compare with skyline plot
sk <- skyline(tree.hiv)
plot(sk, lwd=1, lty=3, show.years=TRUE, subst.rate=0.0023, present.year = 1997)
lines(popsize, show.years=TRUE, subst.rate=0.0023, present.year = 1997)
}
\keyword{manip}

\eof
\name{ratogram}
\alias{ratogram}

\title{Ratogram Computed by Nonparametric Rate Smoothing}
\usage{
ratogram(phy, scale = 1, expo = 2, minEdgeLength = 1e-06)
}
\arguments{
  \item{phy}{A phylogenetic tree (i.e. an object of class \code{"phylo"}), where
    the branch lengths are measured in substitutions.}
  
  \item{scale}{Age of the root in the chronogram corresponding to the inferred ratogram(default value: 0). }
      
  \item{expo}{Exponent in the objective function (default value: 2)}
  
  \item{minEdgeLength}{Minimum edge length in the phylogram (default value: 1e-06). If any branch lengths are
    smaller then they will be set to this value. }
  
}
\description{

 \code{ratogram} computes a ratogram from a phylogram by applying the NPRS
 (nonparametric rate smoothing) algorithm described in Sanderson (1997).
}

\details{
  Please refer to Sanderson (1997) for mathematical details
}

\value{
\code{chronogram} returns an object of class \code{"phylo"}. The branch lengths of this
tree will be the absolute rates estimated for each branch.}

}

\author{Gangolf Jobb (\url{http://www.treefinder.de}) and
Korbinian Strimmer (\url{http://www.stat.uni-muenchen.de/~strimmer/})
}

\seealso{
\code{\link{chronogram}}, 
\code{\link{NPRS.criterion}}.
}


\references{
  Sanderson, M. J. (1997) A nonparametric approach to estimating
    divergence times in the absence of rate constancy. \emph{Molecular
    Biology and Evolution}, \bold{14}, 1218--1231.
}

\examples{
library(ape)

# get tree
data("landplants.newick") # example tree in NH format
tree.landplants <- read.tree(text = landplants.newick)

# plot tree
tree.landplants
plot(tree.landplants, label.offset = 0.001)

# estimate ratogram
rato.plants <- ratogram(tree.landplants)

# plot and write to file
plot(rato.plants, label.offset = 0.001)
write.tree(rato.plants, file = "ratogram.phy")
}
\keyword{manip}

\eof
\name{read.GenBank}
\alias{read.GenBank}
\title{Read DNA Sequences from GenBank via Internet}
\usage{
read.GenBank(access.nb, seq.names = access.nb)
}
\arguments{
  \item{access.nb}{a vector of mode character giving the accession numbers.}
  \item{seq.names}{the names to give to each sequence; by default the
    accession numbers are used.}
}
\description{
  This function connects to the GenBank databasis, and reads nucleotide
  sequences using accession numbers given as arguments.
}
\value{
  A list a DNA sequences each made of a single vector of mode character
  where each element is a nucleotide.
}
\details{
  The function uses the site \url{http://www.ncbi.nlm.nih.gov/} from
  where the sequences are downloaded.
}
\seealso{
  \code{\link{read.dna}}, \code{\link{write.dna}}, \code{\link{dist.dna}}
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\examples{
### This won't work if your computer is not connected
### to internet!!!
###
### Get the 8 sequences of tanagers (Ramphocelus)
### as used in Paradis (1997)
ref <- c("U15717", "U15718", "U15719", "U15720",
         "U15721", "U15722", "U15723", "U15724")
### Copy/paste or type the following commands if you
### want to try them.
\dontrun{
Rampho <- read.GenBank(ref)
### print the first sequence
### (can be done with `Rampho$U15717' as well)
Rampho[[1]]
### print the first sequence in a cleaner way
cat(Rampho[[1]], "\n", sep = "")
}
}
\keyword{IO}

\eof
\name{read.dna}
\alias{read.dna}
\title{Read DNA Sequences in a File}
\usage{
read.dna(file, format = "interleaved", skip = 0,
         nlines = 0, comment.char = "#", seq.names = NULL)
}
\arguments{
  \item{file}{a file name specified by either a variable of mode character,
    or a double-quoted string.}
  \item{format}{a character string specifying the format of the DNA
    sequences. Three choices are possible: \code{"interleaved"},
    \code{"sequential"}, or \code{"fasta"}.}
  \item{skip}{the number of lines of the input file to skip before
    beginning to read data.}
  \item{nlines}{the number of lines to be read (by default the file is
    read untill its end).}
  \item{comment.char}{a single character, the remaining of the line
    after this character is ignored.}
  \item{seq.names}{the names to give to each sequence; by default the
    names read in the file are used.}
}
\description{
  This function reads DNA sequences in a file, and returns a list of DNA
  sequences with the names of the taxa read in the file as names of the
  vectors of the list. In order to be consistent with other functions in
  APE, the sequences are returned in lower case.
}
\value{
  A list a DNA sequences each made of a single vector of mode character
  where each element is a nucleotide.
}
\details{
  This function follows the interleaved and sequential formats defined
  in PHYLIP (Felsenstein, 1993) but with the original feature than there
  is no restriction on the lengths of the taxa names (though a data file
  with 10-characters-long taxa names is fine as well). For these two
  formats, the first line of the file must contain the dimensions of the
  data (the numbers of taxa and the numbers of nucleotides); the
  sequences are considered as aligned and thus must be of the same
  lengths for all taxa. For the FASTA format, the conventions defined in
  the URL below (see References) are followed; the sequences are taken as
  non-aligned. For all formats, the nucleotides can be arranged in any
  way with blanks and line-breaks inside (with the restriction that the
  first ten nucleotides must be contiguous for the interleaved and
  sequential formats, see below). The names of the sequences are read in
  the file unless the `seq.names' option is used. Particularities for
  each format are detailed below.

  \item{Interleaved:}{the function starts to read the sequences when it
    finds 10 contiguous characters belonging to the ambiguity code of
    the IUPAC (namely A, C, G, T, U, M, R, W, S, Y, K, V, H, D, B, and
    N, upper- or lowercase, so you might run into trouble if you have a
    taxa name with 10 contiguous letters among these!). All characters
    before the sequences are taken as the taxa names after removing the
    leading and trailing spaces (so spaces in a taxa name are
    allowed). It is assumed that the taxa names are not repeated in the
    subsequent blocks of nucleotides.}

  \item{Sequential:}{the same criterion than for the interleaved format
    is used to start reading the sequences and the taxa names; the
    sequences are then read until the number of nucleotides specified in
    the first line of the file is reached. This is repeated for each taxa.}

  \item{FASTA:}{This looks like the sequential format but the taxa names
    (or rather a description of the sequence) are on separate lines
    beginning with a `greater than' character ``>'' (there may be
    leading spaces before this character). These lines are taken as taxa
    names after removing the ``>'' and the possible leading and trailing
    spaces. All the data in the file before the first sequence is ignored.}
}
\references{
  Felsenstein, J. (1993) Phylip (Phylogeny Inference Package) version
  3.5c. Department of Genetics, University of Washington.
  \url{http://evolution.genetics.washington.edu/phylip/phylip.html}

  \url{http://www.ncbi.nlm.nih.gov/SNP/iupac.html}

  \url{http://www.ncbi.nlm.nih.gov/BLAST/fasta.html}
}
\seealso{
  \code{\link{read.GenBank}}, \code{\link{write.dna}},
  \code{\link{dist.dna}}, \code{\link{woodmouse}}
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\examples{
### a small extract from `data(woddmouse)'
cat("3 40",
"No305     NTTCGAAAAACACACCCACTACTAAAANTTATCAGTCACT",
"No304     ATTCGAAAAACACACCCACTACTAAAAATTATCAACCACT",
"No306     ATTCGAAAAACACACCCACTACTAAAAATTATCAATCACT",
file = "exdna.txt", sep = "\n")
ex.dna <- read.dna("exdna.txt", format = "sequential")
str(ex.dna)
ex.dna
### the same data in interleaved format...
cat("3 40",
"No305     NTTCGAAAAA CACACCCACT",
"No304     ATTCGAAAAA CACACCCACT",
"No306     ATTCGAAAAA CACACCCACT",
"          ACTAAAANTT ATCAGTCACT",
"          ACTAAAAATT ATCAACCACT",
"          ACTAAAAATT ATCAATCACT",
file = "exdna.txt", sep = "\n")
ex.dna2 <- read.dna("exdna.txt")
### ... and in FASTA format
cat("> No305",
"NTTCGAAAAACACACCCACTACTAAAANTTATCAGTCACT",
"> No304",
"ATTCGAAAAACACACCCACTACTAAAAATTATCAACCACT",
"> No306",
"ATTCGAAAAACACACCCACTACTAAAAATTATCAATCACT",
file = "exdna.txt", sep = "\n")
ex.dna3 <- read.dna("exdna.txt", format = "fasta")
### These are the same!
identical(ex.dna, ex.dna2)
identical(ex.dna, ex.dna3)
unlink("exdna.txt") # clean-up
}
\keyword{IO}

\eof
\name{read.nexus}
\alias{read.nexus}
\title{Read Tree File in Nexus Format}
\usage{
read.nexus(file, tree.names = NULL)
}
\arguments{
  \item{file}{a file name specified by either a variable of mode character,
    or a double-quoted string.}
  \item{tree.names}{if there are several trees to be read, a vector of
    mode character that gives names to the individual trees; if
    \code{NULL} (the default), the trees are named \code{"tree1"},
    \code{"tree2"}, ...}
}
\description{
  This function reads one or several trees in a NEXUS file.
}
\details{
  The present implementation tries to follow as much as possible the
  NEXUS standard. Only the block "TREES" is read; the other data can be
  read with other functions (e.g., \code{\link{read.dna}},
  \code{\link[base]{read.table}}, ...). A trace of the original data is
  kept with the attribute \code{"origin"} (see below).

  `read.nexus' tries to represent correctly trees with a badly
  represented root edge (i.e. with an extra pair of parentheses). For
  instance, the tree "((A:1,B:1):10);" will be read like "(A:1,B:1):10;"
  but a warning message will be issued in the former case as this is
  apparently not a valid Newick format. If there are two root edges
  (e.g., "(((A:1,B:1):10):10);"), then the tree is not read and an error
  message is issued.
}
\value{
  an object of class \code{"phylo"} with the following components:
  \item{edge}{a two-column matrix of mode character where each row
    represents an edge of the tree; the nodes and the tips are
    symbolized with numbers (these numbers are not treated as numeric,
    hence the mode character); the nodes are represented with negative
    numbers (the root being \code{"-1"}), and the tips are represented with
    positive numbers. For each row, the first column gives the
    ancestor. This representation allows an easy manipulation of the
    tree, particularly if it is rooted.}
  \item{edge.length}{a numeric vector giving the lengths of the
    branches given by \code{edge}.}
  \item{tip.label}{a vector of mode character giving the names of the
    tips; the order of the names in this vector corresponds to the
    (positive) number in \code{edge}.}
  \item{node.label}{(optional) a vector of mode character giving the
    names of the nodes (set to \code{NULL} if not available in the file).}
  \item{root.edge}{(optional) a numeric value giving the length of the
    branch at the root is it exists (\code{NULL} otherwise).}

  If several trees are read in the file, the returned object is of class
  \code{c("phylo", "multi.tree")}, and is a list of objects of class
  \code{"phylo"}.

  An attribute \code{"origin"} is further given to the returned object
  which gives the name of the source file (with its path). This is used
  to write a tree in a NEXUS file where all the original data must be
  written (not only the tree) in accordance to the specifications of
  Maddison et al. (1997).
}
\references{
  Maddison, D. R., Swofford, D. L. and Maddison, W. P. (1997) NEXUS: an
  extensible file format for systemaric information. \emph{Systematic
    Biology}, \bold{46}, 590--621.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{read.tree}}, \code{\link{write.nexus}},
  \code{\link{write.tree}}
}
\keyword{manip}
\keyword{IO}

\eof
\name{read.tree}
\alias{read.tree}
\title{Read Tree File in Parenthetic Format}
\usage{
read.tree(file = "", format = "Newick", rooted = TRUE, text = NULL,
          tree.names = NULL, skip = 0, comment.char = "#", ...)
}
\arguments{
  \item{file}{a file name specified by either a variable of mode character,
    or a double-quoted string; if \code{file = ""} (the default) then the
    tree is input on the keyboard, the entry being terminated with a
    blank line.}
  \item{format}{a character giving the format of the tree file; by
    default \code{"Newick"}. Currently only the Newick format is
    available (see \code{\link{read.nexus}} to read trees in Nexus
    files).}
  \item{rooted}{a logical indicating whether the tree is rooted or not;
    defaults to \code{TRUE}. This is currently not implemented, meaning
    that all trees are read as rooted.}
  \item{text}{alternatively, the name of a variable of mode character
    which contains the tree(s) in parenthetic format. By default, this
    is ignored (set to \code{NULL}, meaning that the tree is read in a
    file); if \code{text} is not \code{NULL}, then the argument
    \code{file} is ignored.}
  \item{tree.names}{if there are several trees to be read, a vector of
    mode character that gives names to the individual trees; if
    \code{NULL} (the default), the trees are named \code{"tree1"},
    \code{"tree2"}, ...}
  \item{skip}{the number of lines of the input file to skip before
    beginning to read data (this is passed directly to\code{ scan()}).}
  \item{comment.char}{a single character, the remaining of the line
    after this character is ignored (this is passed directly to
    \code{scan()}).}
  \item{...}{Further arguments to be passed to \code{scan()}.}
}
\description{
  This function reads a file which contains one or several trees in
  parenthetic format known as the Newick or New Hampshire format. 
}
\details{
  The default option for \code{file} allows to type directly the tree on
  the keyboard (or possibly to copy from an editor and paste in R's
  console) with, e.g., \code{mytree <- read.tree()}.

  `read.tree' tries to represent correctly trees with a badly
  represented root edge (i.e. with an extra pair of parentheses). For
  instance, the tree "((A:1,B:1):10);" will be read like "(A:1,B:1):10;"
  but a warning message will be issued in the former case as this is
  apparently not a valid Newick format. If there are two root edges
  (e.g., "(((A:1,B:1):10):10);"), then the tree is not read and an error
  message is issued.
}
\value{
  an object of class \code{"phylo"} with the following components:
  \item{edge}{a two-column matrix of mode character where each row
    represents an edge of the tree; the nodes and the tips are
    symbolized with numbers (these numbers are not treated as numeric,
    hence the mode character); the nodes are represented with negative
    numbers (the root being \code{"-1"}), and the tips are represented with
    positive numbers. For each row, the first column gives the
    ancestor. This representation allows an easy manipulation of the
    tree, particularly if it is rooted.}
  \item{edge.length}{(optional) a numeric vector giving the lengths of the
    branches given by \code{edge}.}
  \item{tip.label}{a vector of mode character giving the names of the
    tips; the order of the names in this vector corresponds to the
    (positive) number in \code{edge}.}
  \item{node.label}{(optional) a vector of mode character giving the
    names of the nodes (set to \code{NULL} if not available in the file).}
  \item{root.edge}{(optional) a numeric value giving the length of the
    branch at the root is it exists (\code{NULL} otherwise).}

  If several trees are read in the file, the returned object is of class
  \code{c("phylo", "multi.tree")}, and is a list of objects of class \code{"phylo"}.
}
\references{
  \url{http://evolution.genetics.washington.edu/phylip/newick_doc.html}

  \url{http://evolution.genetics.washington.edu/phylip/newicktree.html}
}

\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{write.tree}}, \code{\link{read.nexus}},
  \code{\link{write.nexus}}, \code{\link[base]{scan}} for the basic R
  function to read data in a file
}
\examples{
### An extract from Sibley and Ahlquist (1990)
cat("(((Strix_aluco:4.2,Asio_otus:4.2):3.1,",
   "Athene_noctua:7.3):6.3,Tyto_alba:13.5);",
   file = "ex.tre", sep = "\n")
tree.owls <- read.tree("ex.tre")
str(tree.owls)
tree.owls
unlink("ex.tre") # delete the file "ex.tre"
### Only the first three species using the option `text'
TREE <- "((Strix_aluco:4.2,Asio_otus:4.2):3.1,Athene_noctua:7.3);"
TREE
tree.owls.bis <- read.tree(text = TREE)
str(tree.owls.bis)
tree.owls.bis
}
\keyword{manip}
\keyword{IO}

\eof
\name{root}
\alias{root}
\title{Roots Phylogenetic Trees}
\usage{
root(phy, outgroup)
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
  \item{outgroup}{a vector of mode numeric or character specifying the tips
    to delete.}
}
\description{
  This function reroots a phylogenetic tree with respect to the
  specified outgroup.
}
\details{
  The argument \code{outgroup} can be either character or numeric. In
  the first case, it gives the labels of the tips to be deleted; in the
  second case the numbers of these labels in the vector
  \code{phy$tip.label} are given.

  If \code{outgroup} is of length one (i.e. a single value), then the
  tree is rerooted using the node below this tip as the new root.

  If \code{outgroup} is of length two or more, the most recent common
  ancestor (MRCA) is used as the new root. Note that the tree is really
  unrooted before being rerooted, so that if \code{outgroup} is already
  the outgroup, then the returned tree is not the same than the original
  one (see examples). If \code{outgroup} is not monophyletic, the
  operation fails and an error message is issued.
}
\value{
  an object of class \code{"phylo"}.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{bind.tree}}, \code{\link{drop.tip}}
}
\examples{
data(bird.orders)
plot(root(bird.orders, 1))
plot(root(bird.orders, 1:5))
}
\keyword{manip}

\eof
\name{rotate}
\alias{rotate}
\title{Rotate an Internal Branch of a Tree}
\usage{
rotate(phy, group)
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
  \item{group}{a vector of mode numeric or character specifying the tips
    defining the clade to rotate, or the string \code{"all"} meaning to
    rotate the whole tree.}
}
\description{
  This function rotates a clade within a tree.
}
\details{
  The argument \code{outgroup} can be one of the three followings: (1) a
  vector of mode character (= the labels of the tips); (2) a vector of
  mode numeric (= the numbers of these labels in the vector
  \code{phy$tip.label}), or (3) the string \code{"all"}. In cases (1)
  and (2), the clade is rotated around the most recent common ancestor
  of \code{group}. If the latter is not monophyletic, the operation
  fails and an error message is issued.

  Note that the tree returned is the same than the original one, just
  its representation is changed.
}
\value{
  an object of class \code{"phylo"}.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{bind.tree}}, \code{\link{drop.tip}}, \code{\link{root}}
}
\examples{
data(bird.orders)
layout(matrix(1:4, 2, 2))
op <- par(cex = 0.5)
plot(bird.orders)
plot(rotate(bird.orders, 1:5))
plot(rotate(bird.orders, 6:23))
plot(rotate(bird.orders, "all"))
layout(matrix(1))
par(op)
### The tree hasn't changed:
all.equal(bird.orders, rotate(bird.orders, "all"))
}
\keyword{manip}

\eof
\name{rtree}
\alias{rtree}
\title{Generates Random Trees}
\usage{
rtree(n, br = TRUE)
}
\arguments{
  \item{n}{an integer giving the number of tips in the tree.}
  \item{br}{a logical specifying whether the tree should have branch
    lengths (default is \code{TRUE}).}
}
\description{
  This function generates a tree by splitting randomly the edges until
  the specified number of tips is obtained.
}
\details{
  If \code{br = TRUE}, branch lengths are taken from a uniform
  distribution on [0, 1].

  This is an experimental function and is not intended to generate trees
  with given statistical characteristics (at least for the moment). Its
  present purpose is to give a tree of a specified size in an easy
  way. To get an ultrametric tree, one may apply the function
  \code{\link{chronogram}} to the tree generated by \code{rtree}.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\examples{
layout(matrix(1:9, 3, 3))
### Nine random trees:
for (i in 1:9) plot(rtree(20))
### Nine random cladograms:
for (i in 1:9) plot(rtree(20, FALSE), type = "c")
layout(matrix(1))
}
\keyword{datagen}

\eof
\name{seg.sites}
\alias{seg.sites}
\title{
  Find Segregating Sites in DNA Sequences
}
\usage{
seg.sites(X)
}
\arguments{
  \item{X}{a matrix, a data frame, or a list which contains the DNA
    sequences.}
}
\description{
  This function gives the indices of segregating (polymorphic) sites in
  a sample of DNA sequences.
}
\details{
  If the sequences are in a list, all the sequences must be of the same
  length.
}
\value{
  A numeric vector giving the indices of the segregating sites.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\note{
  The present version looks for the sites which are "variable" in the
  data in terms of different \emph{letters}. This may give unexpected
  results if there are ambiguous bases in the data.
}
\seealso{
  \code{\link{base.freq}}, \code{\link{GC.content}},
  \code{\link{theta.s}}
}
\examples{
data(woodmouse)
y <- seg.sites(woodmouse)
y
length(y)
}
\keyword{univar}

\eof
\name{skyline}
\alias{skyline}
\alias{skyline.phylo}
\alias{skyline.coalescentIntervals}
\alias{skyline.collapsedIntervals}
\alias{find.skyline.epsilon}

\title{Skyline Plot Estimate of Effective Population Size}
\usage{
skyline(x, \dots)
skyline.phylo(x, \dots)
skyline.coalescentIntervals(x, epsilon=0, \dots)
skyline.collapsedIntervals(x, old.style=FALSE, \dots)
find.skyline.epsilon(ci, GRID=1000, MINEPS=1e-6, \dots)
}
\arguments{
  \item{x}{Either an ultrametric tree (i.e. an object of class \code{"phylo"}), 
           or coalescent intervals (i.e. an object of class \code{"coalescentIntervals"}), or
	   collapsed coalescent intervals (i.e. an object of class \code{"collapsedIntervals"}).}
  
  \item{epsilon}{collapsing parameter that controls the amount of smoothing
    (allowed range: from \code{0} to \code{ci$total.depth}, default value: 0). This is the same parameter as in
    \link{collapsed.intervals}.}
  
  \item{old.style}{Parameter to choose between two slightly different variants of the
     generalized skyline plot (Strimmer and Pybus, pers. comm.). The default value \code{FALSE} is
     recommended.}
  
  \item{ci}{coalescent intervals (i.e. an object of class \code{"coalescentIntervals"})}
  
  \item{GRID}{Parameter for the grid search for \code{epsilon} in \code{find.skyline.epsilon}.}
  
  \item{MINEPS}{Parameter for the grid search for \code{epsilon} in \code{find.skyline.epsilon}.}
  
  \item{...}{Any of the above parameters.}
  
}
\description{

 \code{skyline} computes the \emph{generalized skyline plot} estimate of effective population size
 from an estimated phylogeny.  The demographic history is approximated by 
 a step-function.  The number of parameters of the skyline plot (i.e. its smoothness)
 is controlled by a parameter \code{epsilon}. 
 
 \code{find.skyline.epsilon} searches for an optimal value of the \code{epsilon} parameter,
 i.e. the value that maximizes the AICc-corrected log-likelihood (\code{logL.AICc}).
}

\details{
\code{skyline} implements the \emph{generalized skyline plot}  introduced in 
Strimmer and Pybus (2001).  For \code{epsilon = 0} the
generalized skyline plot degenerates to the 
\emph{classic skyline plot} described in
Pybus et al. (2000).  The latter is in turn directly related to lineage-through-time plots
(Nee et al., 1995).
}

\value{
\code{skyline} returns an object of class \code{"skyline"} with the following entries:

  \item{time}{ A vector with the time at the end of each coalescent
    interval (i.e. the accumulated interval lengths from the beginning of the first interval
    to the end of an interval)}
 
  \item{interval.length}{ A vector with the length of each 
    interval.}
    
  \item{population.size}{A vector with the effective population size of each interval.}
   
  \item{parameter.count}{ Number of free parameters in the skyline plot.}    
  \item{epsilon}{The value of the underlying smoothing parameter.}
  
  \item{logL}{Log-likelihood of skyline plot (see Strimmer and Pybus, 2001).}
   
  \item{logL.AICc}{AICc corrected log-likelihood (see Strimmer and Pybus, 2001).}

\code{find.skyline.epsilon} returns the value of the \code{epsilon} parameter
   that maximizes \code{logL.AICc}.
}

\author{Korbinian Strimmer (\url{http://www.stat.uni-muenchen.de/~strimmer/})}

\seealso{
\code{\link{coalescent.intervals}}, \code{\link{collapsed.intervals}},
\code{\link{skylineplot}}, \code{\link{ltt.plot}}.
}


\references{
  Strimmer, K. and O.G. Pybus. 2001. Exploring the demographic history
  of DNA sequences using the generalized skyline plot. \emph{Molecular
    Biology and Evolution}, \bold{18}, 2298--2305.

  Pybus, O. G, A. Rambaut and P. H. Harvey (2000) An integrated
  framework for the inference of viral population history from
  reconstructed genealogies. \emph{Genetics}, \bold{155}, 1429--1437.

  Nee, S., E. C. Holmes, A. Rambaut and P. H. Harvey (1995) Inferring
  population history from molecular phylogenies. \emph{Philosophical
    Transactions of the Royal Society of London. Series B. Biological
    Sciences}, \bold{349}, 25--31.
}

\examples{
library(ape)

# get tree
data("hivtree.newick") # example tree in NH format
tree.hiv <- read.tree(text = hivtree.newick) # load tree

# corresponding coalescent intervals
ci <- coalescent.intervals(tree.hiv) # from tree

# collapsed intervals
cl1 <- collapsed.intervals(ci,0)
cl2 <- collapsed.intervals(ci,0.0119)


#### classic skyline plot ####
sk1 <- skyline(cl1)        # from collapsed intervals 
sk1 <- skyline(ci)         # from coalescent intervals
sk1 <- skyline(tree.hiv)   # from tree
sk1

plot(skyline(tree.hiv))
skylineplot(tree.hiv) # shortcut

plot(sk1, show.years=TRUE, subst.rate=0.0023, present.year = 1997)

#### generalized skyline plot ####

sk2 <- skyline(cl2)              # from collapsed intervals
sk2 <- skyline(ci, 0.0119)       # from coalescent intervals
sk2 <- skyline(tree.hiv, 0.0119) # from tree
sk2

plot(sk2)


# classic and generalized skyline plot together in one plot
plot(sk1, show.years=TRUE, subst.rate=0.0023, present.year = 1997, col=c(grey(.8),1))
lines(sk2,  show.years=TRUE, subst.rate=0.0023, present.year = 1997)
legend(.15,500, c("classic", "generalized"), col=c(grey(.8),1),lty=1)


# find optimal epsilon parameter using AICc criterion
find.skyline.epsilon(ci)

sk3 <- skyline(ci, -1) # negative epsilon also triggers estimation of epsilon
sk3$epsilon
}
\keyword{manip}

\eof
\name{skylineplot}
\alias{skylineplot}
\alias{plot.skyline}
\alias{lines.skyline}
\alias{skylineplot.deluxe}

\title{Drawing Skyline Plot Graphs}
\usage{
\method{plot}{skyline}(x, show.years=FALSE, subst.rate, present.year, \dots)
\method{lines}{skyline}(x, show.years=FALSE, subst.rate, present.year, \dots)
skylineplot(z, \dots)
skylineplot.deluxe(tree, \dots)
}
\arguments{
  \item{x}{skyline plot data (i.e. an object of class \code{"skyline"}).}
  
  \item{z}{Either an ultrametric tree (i.e. an object of class \code{"phylo"}), 
           or coalescent intervals (i.e. an object of class \code{"coalescentIntervals"}), or
	   collapsed coalescent intervals (i.e. an object of class \code{"collapsedIntervals"}).}
  

  \item{tree}{ultrametric tree (i.e. an object of class \code{"phylo"}).}
  
  
  \item{show.years}{option that determines whether the time is plotted in units of
        of substitutions (default) or in years (requires specification of substution rate
	and year of present).}

	
 \item{subst.rate}{substitution rate (see option show.years).}	
 \item{present.year}{present year (see option show.years).}	

  \item{\dots}{further arguments to be passed on to \code{skyline()} and \code{plot()}.} 
	 
}
\description{

 These functions provide various ways to draw \emph{skyline plot} graphs
 on the current graphical device. Note that \code{skylineplot(z, \dots)} is simply
 a shortcut for \code{plot(skyline(z, \dots))}.
 The skyline plot itself is an estimate of effective population size through time,
 and is computed using the function \code{\link{skyline}}.
}

\details{
 See \code{\link{skyline}} for more details (incl. references) about the skyline plot method.
}


\author{Korbinian Strimmer (\url{http://www.stat.uni-muenchen.de/~strimmer/})}

\seealso{
\code{\link[base]{plot}} and \code{\link[base]{lines}} for the basic plotting
function in R, \code{\link{coalescent.intervals}}, \code{\link{skyline}}
}

\examples{
library(ape)

# get tree
data("hivtree.newick") # example tree in NH format
tree.hiv <- read.tree(text = hivtree.newick) # load tree


#### classic skyline plot
skylineplot(tree.hiv) # shortcut


#### plot classic and generalized skyline plots and estimate epsilon
sk.opt <- skylineplot.deluxe(tree.hiv) 
sk.opt$epsilon


#### classic and generalized skyline plot ####
sk1 <- skyline(tree.hiv)   
sk2 <- skyline(tree.hiv, 0.0119) 

# use years rather than substitutions as unit for the time axis
plot(sk1, show.years=TRUE, subst.rate=0.0023, present.year = 1997, col=c(grey(.8),1))
lines(sk2,  show.years=TRUE, subst.rate=0.0023, present.year = 1997)
legend(.15,500, c("classic", "generalized"), col=c(grey(.8),1),lty=1)


#### various skyline plots for different epsilons
layout(mat= matrix(1:6,2,3,byrow=TRUE))
ci <- coalescent.intervals(tree.hiv)
plot(skyline(ci, 0.0));title(main="0.0")
plot(skyline(ci, 0.007));title(main="0.007")
plot(skyline(ci, 0.0119),col=4);title(main="0.0119")
plot(skyline(ci, 0.02));title(main="0.02")
plot(skyline(ci, 0.05));title(main="0.05")
plot(skyline(ci, 0.1));title(main="0.1")
layout(mat= matrix(1:1,1,1,byrow=TRUE))
}
\keyword{hplot}

\eof
\name{summary.phylo}
\alias{summary.phylo}
\title{Print Summary of a Phylogeny}
\usage{
\method{summary}{phylo}(object, \dots)
}
\arguments{
  \item{object}{an object of class \code{"phylo"}.}
  \item{...}{further arguments passed to or from other methods.}
}
\description{
  This function prints a compact summary of a phylogenetic tree (an
  object of class \code{"phylo"}).
}
\details{
  The summary includes the numbers of tips and of nodes, summary
  statistics of the branch lengths (if they are available) with mean,
  variance, minimum, first quartile, median, third quartile, and
  maximum, listing of the first ten tip labels, and (if available) of
  the first ten node labels. It is also printed whether some of these
  optional elements (branch lengths, node labels, and root edge) are not
  found in the tree.

  This function simply prints its results on the standard output and is
  not meant for programming.
}
\value{
  A NULL value is returned, the results are simply printed.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{read.tree}}, \code{\link[base]{summary}} for the generic R
  function
}
\examples{
data(bird.families)
summary(bird.families)
}
\keyword{manip}

\eof
\name{theta.h}
\alias{theta.h}
\title{Population Parameter THETA using Homozygosity}
\usage{
theta.h(x, standard.error = FALSE)
}
\arguments{
  \item{x}{a vector or a factor.}
  \item{standard.error}{a logical indicating whether the standard error
    of the estimated theta should be returned (\code{TRUE}), the default
    being \code{FALSE}.}
}
\description{
  This function computes the population parameter THETA using the
  homozygosity (or mean heterozygosity) from gene frequencies.
}
\value{
  a numeric vector of length one with the estimated theta (the default),
  or of length two if the standard error is returned
  (\code{standard.error = TRUE}).
}
\details{
  The argument \code{x} can be either a factor or a vector. If it is a
  factor, then it is taken to give the individual alleles in the
  population. If it is a numeric vector, then its values are taken to be
  the numbers of each allele in the population. If it is a non-numeric
  vector, it is a coerced as a factor.

  The standard error is computed with an approximation due to
  Chakraborty and Weiss (1991).
}
\references{
  Zouros, E. (1979) Mutation rates, population sizes and amounts of
  electrophoretic variation at enzyme loci in natural
  populations. \emph{Genetics}, \bold{92}, 623--646.
  
  Chakraborty, R. and Weiss, K. M. (1991) Genetic variation of the
  mitochondrial DNA genome in American Indians is at mutation-drift
  equilibrium. \emph{American Journal of Human Genetics}, \bold{86}, 497--506.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{heterozygosity}}, \code{\link{theta.s}}, \code{\link{theta.k}}
}
\keyword{manip}
\keyword{univar}

\eof
\name{theta.k}
\alias{theta.k}
\title{Population Parameter THETA using Expected Number of Alleles}
\usage{
theta.k(x, n = NULL, k = NULL)
}
\arguments{
  \item{x}{a vector or a factor.}
  \item{n}{a numeric giving the sample size.}
  \item{k}{a numeric giving the number of alleles.}
}
\description{
  This function computes the population parameter THETA using the
  expected number of alleles.
}
\value{
  a numeric vector of length one with the estimated theta.
}
\details{
  This function can be used in two ways: either with a vector giving the
  individual genotypes from which the sample size and number of alleles
  are derived (\code{theta.k(x)}), or giving directly these two
  quantities (\code{theta.k(n, k)}).
  
  The argument \code{x} can be either a factor or a vector. If it is a
  factor, then it is taken to give the individual alleles in the
  population. If it is a numeric vector, then its values are taken to be
  the numbers of each allele in the population. If it is a non-numeric
  vector, it is a coerced as a factor.

  Both arguments \code{n} and \code{k} must be single numeric values.
}
\note{
  For the moment, no standard-error or confidence interval is computed.
}
\references{
  Ewens, W. J. (1972) The sampling theory of selectively neutral
  alleles. \emph{Theoretical Population Biology}, \bold{3}, 87--112.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{theta.h}}, \code{\link{theta.s}}
}
\keyword{manip}
\keyword{univar}

\eof
\name{theta.s}
\alias{theta.s}
\title{Population Parameter THETA using Segregating Sites
  in DNA Sequences}
\usage{
theta.s(s, n, variance = FALSE)
}
\arguments{
  \item{s}{a numeric giving the number of segregating sites.}
  \item{n}{a numeric giving the length of the sequences (i.e. the number
    of sites under study).}
  \item{variance}{a logical indicating whether the variance of the 
    estimated THETA should be returned (\code{TRUE}), the default being
    \code{FALSE}.}
}
\description{
  This function computes the population parameter THETA using the
  number of segregating sites \code{s} in a sample of \code{n} DNA sequences.
}
\value{
  a numeric vector of length one with the estimated theta (the default),
  or of length two if the standard error is returned
  (\code{variance = TRUE}).
}
\note{
  The number of segregating sites needs to be computed beforehand, for
  instance with the function \code{seg.sites} (see example below).
}
\references{
  Watterson, G. (1975) On the number of segragating sites in genetical
  models without recombination. \emph{Theoretical Population Biology},
  \bold{7}, 256--276.
  
  Tajima, F. (1989) Statistical method for testing the neutral mutation
  hypothesis by DNA polymorphism. \emph{Genetics}, \bold{123}, 585--595.
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{theta.h}}, \code{\link{theta.k}}, \code{\link{seg.sites}}
}
\examples{
data(woodmouse)
y <- seg.sites(woodmouse)
s <- length(y)
n <- length(woodmouse[[1]])
theta.s(s, n)
theta.s(s, n, variance = TRUE)
}
\keyword{manip}
\keyword{univar}

\eof
\name{vcv.phylo}
\alias{vcv.phylo}
\title{Phylogenetic Variance-covariance or Correlation Matrix}
\usage{
vcv.phylo(phy, model = "Brownian", cor = FALSE)
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
  \item{model}{a character giving the model used to compute the
    variances and covariances of the phynotype; by default
    \code{"Brownian"}. Currently only the Brownian model is available.}
  \item{cor}{a logical indicating whether the correlation matrix should
    be returned (\code{TRUE}); by default the variance-covariance matrix
    is returned (\code{FALSE}).}
}
\description{
  This function computes the expected variances and covariances of a
  continuous phenotype assuming it evolves under a given model
  (currently only the model of Brownian motion is available).
}
\value{
  a numeric matrix with the names of the tips (as given by the \code{tip.label}
  of the argument \code{phy}) as colnames and rownames.
}
\references{
  Garland, T. Jr. and Ives, A. R. (2000) Using the past to predict the
  present: confidence intervals for regression equations in phylogenetic
  comparative methods. \emph{American Naturalist}, \bold{155}, 346--364.
}

\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{read.tree}} to read tree files in Newick format
}
\keyword{manip}
\keyword{multivariate}

\eof
\name{woodmouse}
\alias{woodmouse}
\title{Cytochrome b Sequences of Woodmice}
\description{
  This is a set of 15 sequences of the mitochondrial gene cytochrome
  \emph{b} of the woodmouse (\emph{Apodemus sylvaticus}) which is a
  subset of the data analysed by Michaux et al. (2003). The full data
  set is available through GenBank (accession numbers AJ511877 to
  AJ511987).
}
\usage{
data(woodmouse)
}
\format{
  The data are stored in an ASCII file using the sequential format for
  DNA sequences which is read with `read.dna()'.
}
\source{
  Michaux, J. R., Magnanou, E., Paradis, E., Nieberding, C. and Libois,
  R. (2003) Mitochondrial phylogeography of the Woodmouse (Apodemus
  sylvaticus) in the Western Palearctic region. \emph{Molecular
    Ecology}, \bold{12}, 685--697.
}
\seealso{
  \code{\link{read.dna}}, \code{\link{dist.dna}}
}
\examples{
data(woodmouse)
str(woodmouse)
}
\keyword{datasets}

\eof
\name{write.dna}
\alias{write.dna}
\title{Write DNA Sequences in a File}
\usage{
write.dna(x, file, format = "interleaved", append = FALSE,
          nbcol = 6, colsep = " ", colw = 10, indent = NULL,
          blocksep = 1)
}
\arguments{
  \item{x}{a list a DNA sequences each made of a single vector of mode
    character where each element is a nucleotide.}
  \item{file}{a file name specified by either a variable of mode character,
    or a double-quoted string.}
  \item{format}{a character string specifying the format of the DNA
    sequences. Three choices are possible: \code{"interleaved"},
    \code{"sequential"}, or \code{"fasta"}, or any unambiguous
    abbreviation of these.}
  \item{append}{a logical, if \code{TRUE} the data are appended to the
    file without erasing the data possibly existing in the file,
    otherwise the file (if it exists) is overwritten (\code{FALSE} the
    default).}
  \item{nbcol}{a numeric specifying the number of columns per row (6 by
    default); may be negative implying that the nucleotides are printed
    on a single line.}
  \item{colsep}{a character used to separate the columns (a single
    space by default).}
  \item{colw}{a numeric specifying the number of nucleotides per column
    (10 by default).}
  \item{indent}{a numeric or a character specifying how the blocks of
    nucleotides are indented (see details).}
  \item{blocksep}{a numeric specifying the number of lines between the
    blocks of nucleotides (this has an effect only if `format =
    "interleaved"').}
}
\description{
  This function writes in a file a list of DNA sequences using either a
  sequential or an interleaved format. The names of the vectors of the
  list are used as taxa names.
}
\details{
  The same three formats are supported in the present function than in
  \code{\link{read.dna}}: see its help page and the references below for
  a description of these formats.
  
  If the sequences have no names, then they are given "1", "2", ... as
  names in the file.

  With the interleaved and sequential formats, the sequences must be all
  of the same length; if the taxon names are longer than 10 characters,
  they are truncated and a warning message is issued.
  
  The argument `indent' specifies how the rows of nucleotides are
  indented. In the interleaved and sequential formats, the rows with
  the taxon names are never indented; the subsequent rows are indented
  with 10 spaces by default (i.e. if `indent = NULL)'. In the FASTA
  format, the rows are not indented by default. This default behaviour
  can be modified by specifying a value to `indent': the rows are then
  indented with `indent' (if it is a character) or `indent' spaces (if
  it is a numeric). For example, specifying `indent = "   "' or `indent
  = 3' will have exactly the same effect (use `indent = "\t"' for a
  tabulation).
}
\note{
  Specifying a negative value for `nbcol' (meaning that the nucleotides
  are printed on a single line) gives the same result for the
  interleaved and sequential formats.

  The different options are intended to give flexibility in formatting
  the sequences. For instance, if the sequences are very long it may be
  judicious to remove all the spaces beween columns `(colsep = ""), in
  the margins (indent = 0), and between the blocks (blocksep = 0) to
  produce a smaller file.
}
\value{
  None (invisible `NULL').
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\references{
  Felsenstein, J. (1993) Phylip (Phylogeny Inference Package) version
  3.5c. Department of Genetics, University of Washington.
  \url{http://evolution.genetics.washington.edu/phylip/phylip.html}

  \url{http://www.ncbi.nlm.nih.gov/SNP/iupac.html}

  \url{http://www.ncbi.nlm.nih.gov/BLAST/fasta.html}
}
\seealso{
  \code{\link{read.dna}}, \code{\link{read.GenBank}}
}
\keyword{IO}

\eof
\name{write.nexus}
\alias{write.nexus}
\title{Write Tree File in Nexus Format}
\usage{
write.nexus(phy, file = "", translate = TRUE, original.data = TRUE)
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
  \item{file}{a file name specified by either a variable of mode character,
    or a double-quoted string; if \code{file = ""}(the default) then the
    tree is written on the standard output connection.}
  \item{translate}{a logical, if \code{TRUE} (the default) a translation
    of the tip labels is done which are replaced in the parenthetic
    representation with tokens.}
  \item{original.data}{a logical, if \code{TRUE} (the default) the
    data in the original NEXUS file are eventually written in
    \code{"file"} (see below).}
}
\description{
  This function writes a tree in a file with the NEXUS format.
}
\details{
  If \code{original.data = TRUE}, the file as specified by the attribute
  \code{"origin"} of \code{phy} is read and its data (except the trees)
  are written in \code{file}.

  Currently, only a single tree can be written in \code{file}.
}
\value{
  None (invisible `NULL').
}
\references{
  Maddison, D. R., Swofford, D. L. and Maddison, W. P. (1997) NEXUS: an
  extensible file format for systemaric information. \emph{Systematic
    Biology}, \bold{46}, 590--621.
}

\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{read.nexus}}, \code{\link{read.tree}},
  \code{\link{write.tree}}

}
\keyword{manip}
\keyword{IO}

\eof
\name{write.tree}
\alias{write.tree}
\title{Write Tree File in Parenthetic Format}
\usage{
write.tree(phy, file = "", append = FALSE, format = "Newick")
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
  \item{file}{a file name specified by either a variable of mode character,
    or a double-quoted string; if \code{file = ""}(the default) then the
    tree is written on the standard output connection.}
  \item{append}{a logical, if \code{TRUE} the tree is appended to the file
    without erasing the data possibly existing in the file, otherwise
    the file (if it exists) is overwritten (\code{FALSE} the default).}
  \item{format}{a character giving the format of the tree file; by
    default \code{"Newick"}. Currently only \code{"Newick"} is available.}
}
\description{
  This function writes in a file a tree in parenthetic format using the
  Newick or New Hampshire format.
}
\value{
  None (invisible `NULL').
}
\details{
  The node labels and the root edge length, if available, are written in
  the file.
}
\references{
  \url{http://evolution.genetics.washington.edu/phylip/newick_doc.html}

  \url{http://evolution.genetics.washington.edu/phylip/newicktree.html}
}

\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{read.tree}}, \code{\link{read.nexus}},
  \code{\link{write.nexus}}
}
\keyword{manip}
\keyword{IO}

\eof
\name{xenarthra}
\alias{xenarthra}
\title{Molecular Phylogeny of Living Xenarthrans}
\description{
  This phylogeny was inferred by maximum likelihood analysis of the
  nuclear gene BRCA1 (breast cancer susceptibility, 2788 sites)
  sequences for 47 placental and 3 marsupial taxa.
}
\usage{
data(xenarthra)
}
\format{
  The data are stored as an object of class \code{"phylo"} which
  structure is described in the help page of the function
  \code{\link{read.tree}}.
}
\source{
  Delsuc, F., Scally, M., Madsen, O., Stanhope, M. J., de Jong, W. W.,
  Catzeflis, F. M., Springer, M. S. and Douzery, E. J. P. (2002)
  Molecular phylogeny of living xenarthrans and the impact of character
  and taxon sampling on the placental tree rooting. \emph{Molecular
    Biology and Evolution}, \bold{19}, 1656--1671.
}
\seealso{
  \code{\link{read.tree}}
}
\examples{
data(xenarthra)
op <- par()
\dontrun{par(ask = TRUE)}
plot(xenarthra)
### remove the margins...
plot(xenarthra, no.margin = TRUE)
### ... and use a smaller font size
par(cex = 0.8)
plot(xenarthra, no.margin = TRUE)
par(op)
}
\keyword{datasets}

\eof
\name{yule}
\alias{yule}
\title{Fits Yule Model to a Phylogenetic Tree}
\usage{
yule(phy)
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
}
\description{
  This function fits by maximum likelihood a Yule model, i.e. a
  birth-only model to the branching times computed from a phylogenetic
  tree.
}
\details{
  The tree must be fully dichotomous.

  The maximum likelihood estimate of the speciation rate is obtained by
  the ratio of the number of speciation events on the cumulative number
  of species through time; these two quantities are obtained with the
  number of nodes in the tree, and the sum of the branch lengths,
  respectively.

  If there is a `root.edge' element in the phylogenetic tree, then it is
  assumed that it has a biological meaning and is counted as a branch
  length, and the root is counted as a speciation event; otherwise the
  number of speciation events is the number of nodes - 1.

  The standard-error of lambda is computed with the second derivative of
  the log-likelihood function.
}
\value{
  An object of class "yule" which is a list with the following
  components:
  \item{lambda}{the maximum likelihood estimate of the speciation
    (birth) rate.}
  \item{se}{the standard-error of lambda.}
  \item{loglik}{the log-likelihood at its maximum.}
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{branching.times}}, \code{\link{diversi.gof}},
  \code{\link{diversi.time}}, \code{\link{ltt.plot}},
  \code{\link{birthdeath}}, \code{\link{bd.ext}}
}
\keyword{models}

\eof
\name{zoom}
\alias{zoom}
\title{Zoom on a Portion of a Phylogeny}
\description{
  This function plots simultaneously a whole phylogenetic tree
  (supposedly large) and a portion of it.
}
\usage{
zoom(phy, focus, type = "phylogram", use.edge.length = TRUE)
}
\arguments{
  \item{phy}{an object of class \code{"phylo"}.}
  \item{focus}{a vector, either numeric or character, specifying the
    tips to be focused on.}
  \item{type}{a character string specifying the type of phylogeny to be
    drawn; it must be one of "phylogram" (the default), "cladogram",
    "unrooted", or any unambiguous abbreviation of these.}
  \item{use.edge.length}{a logical indicating whether to use the edge
    lengths of the phylogeny to draw the branches (the default) or not
    (if \code{FALSE}). This option has no effect if the object of class
    \code{"phylo"} has no `edge.length' element.}
}
\details{
  This is an experimental function aimed at exploring very large
  trees. The main argument is a phylogenetic tree, and the second one is
  a vector specifying the tips to be focused on. The latter can be
  either numeric and is thus taken as the index of the tip labels, or
  character in which case it is taken as the corresponding tip labels.

  The plot consists of two trees: the whole tree is plotted on the
  left-hand side in a narrower sub-window (about a quarter of the
  device) without any tip labels; the sub-tree consisting of the tips
  in `focus' is extracted and plotted on the right-hand side. The tips
  in `focus' are marked on the left-hand side tree with a blue "o".
}
\author{Emmanuel Paradis \email{paradis@isem.univ-montp2.fr}}
\seealso{
  \code{\link{plot.phylo}}, \code{\link{drop.tip}},
  \code{\link[base]{layout}}
}
\examples{
data(chiroptera)
zoom(chiroptera, 1:20)
}
\keyword{hplot}

\eof
